@@ -1,7 +1,7 @@
 #
 # Chris Lumens <clumens@redhat.com>
 #
-# Copyright 2006, 2007, 2008 Red Hat, Inc.
+# Copyright 2006, 2007, 2008, 2012 Red Hat, Inc.
 #
 # This copyrighted material is made available to anyone wishing to use, modify,
 # copy, or redistribute it subject to the terms and conditions of the GNU
@@ -15,7 +15,7 @@
 # Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  Any Red Hat
 # trademarks that are incorporated in the source code or documentation are not
 # subject to the GNU General Public License and may only be used or replicated
-# with the express permission of Red Hat, Inc. 
+# with the express permission of Red Hat, Inc.
 #
 """
 Base classes for creating commands and syntax version object.
@@ -34,20 +34,23 @@ This module exports several important base classes:
                         a subclass is used, a warning message will be
                         printed.
 
+    RemovedCommand - an abstract subclass of KickstartCommand that should
+                     be subclassed to update the description with the version
+                     it was removed in.
+                     Any use of the command will raise an error.
+
     KickstartCommand - The base abstract class for all kickstart commands.
                        Command objects are contained within a BaseHandler
                        object.
 """
-import gettext
-gettext.textdomain("pykickstart")
-_ = lambda x: gettext.ldgettext("pykickstart", x)
+from pykickstart.i18n import _
 
-import types
 import warnings
-from pykickstart.errors import *
-from pykickstart.ko import *
-from pykickstart.parser import Packages,TpkPackages
+from pykickstart import __version__
+from pykickstart.errors import KickstartParseError, KickstartParseWarning, KickstartDeprecationWarning
+from pykickstart.ko import KickstartObject
 from pykickstart.version import versionToString
+from pykickstart.parser import Packages, TpkPackages
 
 ###
 ### COMMANDS
@@ -70,6 +73,10 @@ class KickstartCommand(KickstartObject):
                             command is contained withing.  This is needed to
                             allow referencing of Data objects.
            lineno        -- The current line number in the input file.
+           seen          -- If this command was ever used in the kickstart file,
+                            this attribute will be set to True.  This allows
+                            for differentiating commands that were omitted
+                            from those that default to unset.
            writePriority -- An integer specifying when this command should be
                             printed when iterating over all commands' __str__
                             methods.  The higher the number, the later this
@@ -79,7 +86,7 @@ class KickstartCommand(KickstartObject):
 
         # We don't want people using this class by itself.
         if self.__class__ is KickstartCommand:
-            raise TypeError ("KickstartCommand is an abstract class.")
+            raise TypeError("KickstartCommand is an abstract class.")
 
         KickstartObject.__init__(self, *args, **kwargs)
 
@@ -90,20 +97,21 @@ class KickstartCommand(KickstartObject):
         self.currentLine = ""
         self.handler = None
         self.lineno = 0
+        self.seen = False
 
-        # If a subclass provides a removedKeywords list, remove all the
-        # members from the kwargs list before we start processing it.  This
-        # ensures that subclasses don't continue to recognize arguments that
-        # were removed.
-        for arg in filter(kwargs.has_key, self.removedKeywords):
-            kwargs.pop(arg)
+        # If a subclass provides a removedKeywords list, warn if the user
+        # continues to use some of the removed keywords
+        for arg in (kw for kw in self.removedKeywords if kw in kwargs):
+            warnings.warn("The '%s' keyword has been removed." % arg, KickstartParseWarning, stacklevel=2)
 
     def __call__(self, *args, **kwargs):
         """Set multiple attributes on a subclass of KickstartCommand at once
            via keyword arguments.  Valid attributes are anything specified in
            a subclass, but unknown attributes will be ignored.
         """
-        for (key, val) in kwargs.items():
+        self.seen = True
+
+        for (key, val) in list(kwargs.items()):
             # Ignore setting attributes that were removed in a subclass, as
             # if they were unknown attributes.
             if key in self.removedAttrs:
@@ -118,18 +126,13 @@ class KickstartCommand(KickstartObject):
         """
         return KickstartObject.__str__(self)
 
+    # pylint: disable=unused-argument
     def parse(self, args):
         """Parse the list of args and set data on the KickstartCommand object.
            This method must be provided by all subclasses.
         """
-        raise TypeError ("parse() not implemented for KickstartCommand")
-
-    def apply(self, instroot="/"):
-        """Write out the configuration related to the KickstartCommand object.
-           Subclasses which do not provide this method will not have their
-           configuration written out.
-        """
-        return
+        raise TypeError("parse() not implemented for KickstartCommand")
+    # pylint: enable=unused-argument
 
     def dataList(self):
         """For commands that can occur multiple times in a single kickstart
@@ -138,29 +141,51 @@ class KickstartCommand(KickstartObject):
         """
         return None
 
+    @property
+    def dataClass(self):
+        """For commands that can occur multiple times in a single kickstart
+           file, return the class that should be used to store the data from
+           each invocation.  An instance of this class will be appended to
+           dataList.  For all other commands, return None.
+        """
+        return None
+
     def deleteRemovedAttrs(self):
         """Remove all attributes from self that are given in the removedAttrs
            list.  This method should be called from __init__ in a subclass,
            but only after the superclass's __init__ method has been called.
         """
-        for attr in filter(lambda k: hasattr(self, k), self.removedAttrs):
+        for attr in [k for k in self.removedAttrs if hasattr(self, k)]:
             delattr(self, attr)
 
-    # Set the contents of the opts object (an instance of optparse.Values
-    # returned by parse_args) as attributes on the KickstartCommand object.
-    # It's useful to call this from KickstartCommand subclasses after parsing
-    # the arguments.
-    def _setToSelf(self, optParser, opts):
-        self._setToObj(optParser, opts, self)
+    def set_to_self(self, namespace):
+        """Set the contents of the namespace object (an instance of argparse.Namespace
+           returned by parse_arguments) as attributes on the KickstartCommand object.
+           It's useful to call this from KickstartCommand subclasses after parsing
+           the arguments.
+        """
+        self.set_to_obj(namespace, self)
 
-    # Sets the contents of the opts object (an instance of optparse.Values
-    # returned by parse_args) as attributes on the provided object obj.  It's
-    # useful to call this from KickstartCommand subclasses that handle lists
-    # of objects (like partitions, network devices, etc.) and need to populate
-    # a Data object.
-    def _setToObj(self, optParser, opts, obj):
-        for key in filter (lambda k: getattr(opts, k) != None, optParser.keys()):
-            setattr(obj, key, getattr(opts, key))
+    # Just calls set_to_self - exists for backwards compatibility.
+    def _setToSelf(self, namespace):
+        warnings.warn("_setToSelf has been renamed to set_to_self.  The old name will be removed in a future release.", PendingDeprecationWarning, stacklevel=2)
+        self.set_to_self(namespace)
+
+    def set_to_obj(self, namespace, obj):
+        """Sets the contents of the namespace object (an instance of argparse.Namespace
+           returned by parse_arguments) as attributes on the provided object obj.  It's
+           useful to call this from KickstartCommand subclasses that handle lists
+           of objects (like partitions, network devices, etc.) and need to populate
+           a Data object.
+        """
+        for (key, val) in vars(namespace).items():
+            if val is not None:
+                setattr(obj, key, val)
+
+    # Just calls set_to_obj - exists for backwards compatibility.
+    def _setToObj(self, namespace, obj):
+        warnings.warn("_setToObj has been renamed to set_to_obj.  The old name will be removed in a future release.", PendingDeprecationWarning, stacklevel=2)
+        self.set_to_obj(namespace, obj)
 
 class DeprecatedCommand(KickstartCommand):
     """Specify that a command is deprecated and no longer has any function.
@@ -170,12 +195,21 @@ class DeprecatedCommand(KickstartCommand):
     """
     def __init__(self, writePriority=None, *args, **kwargs):
         # We don't want people using this class by itself.
-        if self.__class__ is KickstartCommand:
-            raise TypeError ("DeprecatedCommand is an abstract class.")
+        if self.__class__ is DeprecatedCommand:
+            raise TypeError("DeprecatedCommand is an abstract class.")
 
         # Create a new DeprecatedCommand instance.
         KickstartCommand.__init__(self, writePriority, *args, **kwargs)
 
+    def dataList(self):
+        """Override the method of the deprecated command."""
+        return None
+
+    @property
+    def dataClass(self):
+        """Override the attribute of the deprecated command."""
+        return None
+
     def __str__(self):
         """Placeholder since DeprecatedCommands don't work anymore."""
         return ""
@@ -183,24 +217,226 @@ class DeprecatedCommand(KickstartCommand):
     def parse(self, args):
         """Print a warning message if the command is seen in the input file."""
         mapping = {"lineno": self.lineno, "cmd": self.currentCmd}
-        warnings.warn(_("Ignoring deprecated command on line %(lineno)s:  The %(cmd)s command has been deprecated and no longer has any effect.  It may be removed from future releases, which will result in a fatal error from kickstart.  Please modify your kickstart file to remove this command.") % mapping, DeprecationWarning)
+        warnings.warn(_("Ignoring deprecated command on line %(lineno)s:  The %(cmd)s command has been deprecated and no longer has any effect.  It may be removed from future releases, which will result in a fatal error from kickstart.  Please modify your kickstart file to remove this command.") % mapping, KickstartDeprecationWarning)
+        return None
 
+class RemovedCommand(KickstartCommand):
+    """Specify that a command has been removed and no longer has any function.
+       Any command that is removed should be subclassed from this class, and
+       should set its description to add the version that the command was removed in.
+       This is an abstract class.
+    """
+    def __init__(self, writePriority=None, *args, **kwargs):
+        # We don't want people using this class by itself.
+        if self.__class__ is RemovedCommand:
+            raise TypeError("RemovedCommand is an abstract class.")
+
+        # Create a new RemovedCommand instance.
+        KickstartCommand.__init__(self, writePriority, *args, **kwargs)
+
+    def dataList(self):
+        """Override the method of the removed command."""
+        return None
+
+    @property
+    def dataClass(self):
+        """Override the attribute of the removed command."""
+        return None
+
+    def __str__(self):
+        """Placeholder since RemovedCommands don't work anymore."""
+        return ""
+
+    def parse(self, args):
+        """Raise an error if the command is found in the input file"""
+        raise KickstartParseError(_("%s has been removed.") % self.currentCmd, lineno=self.lineno)
 
 ###
 ### HANDLERS
 ###
-class BaseHandler(KickstartObject):
-    """Each version of kickstart syntax is provided by a subclass of this
-       class.  These subclasses are what users will interact with for parsing,
-       extracting data, and writing out kickstart files.  This is an abstract
-       class.
+class KickstartHandler(KickstartObject):
+    """An empty kickstart handler.
+
+       This handler doesn't handle anything by default.
 
        version -- The version this syntax handler supports.  This is set by
-                  a class attribute of a BaseHandler subclass and is used to
+                  a class attribute of a KickstartHandler subclass and is used to
                   set up the command dict.  It is for read-only use.
     """
     version = None
 
+    def __init__(self, *args, **kwargs):
+        """Create a new KickstartHandler instance.
+
+           Instance attributes:
+
+           commands -- A mapping from a string command to a KickstartCommand
+                       subclass object that handles it.  Multiple strings can
+                       map to the same object, but only one instance of the
+                       command object should ever exist.  Most users should
+                       never have to deal with this directly, as it is
+                       manipulated internally and called through dispatcher.
+           currentLine -- The current unprocessed line from the input file
+                          that caused this handler to be run.
+        """
+        KickstartObject.__init__(self, *args, **kwargs)
+
+        # These will be set by the dispatcher.
+        self.commands = {}
+        self.currentLine = ""
+
+        # A dict keyed by an integer priority number, with each value being a
+        # list of KickstartCommand subclasses.  This dict is maintained by
+        # registerCommand and used in __str__.  No one else should be touching
+        # it.
+        self._writeOrder = {}
+
+    def __str__(self):
+        """Return a string formatted for output to a kickstart file."""
+        retval = ""
+
+        lst = list(self._writeOrder.keys())
+        lst.sort()
+
+        for prio in lst:
+            for obj in self._writeOrder[prio]:
+                retval += obj.__str__()
+
+        return retval
+
+    def _insertSorted(self, lst, obj):
+        def cmdName(cmdObj):
+            if cmdObj.__class__.__name__.find("_") != -1:
+                return cmdObj.__class__.__name__.split("_", 1)[1]
+            else:
+                return cmdObj.__class__.__name__
+
+        length = len(lst)
+        i = 0
+
+        while i < length:
+            # If the two classes have the same name, it's because we are
+            # overriding an existing class with one from a later kickstart
+            # version, so remove the old one in favor of the new one.
+            if cmdName(obj) > cmdName(lst[i]):
+                i += 1
+            elif cmdName(obj) == cmdName(lst[i]):
+                lst[i] = obj
+                return
+            elif cmdName(obj) < cmdName(lst[i]):
+                break
+
+        if i >= length:
+            lst.append(obj)
+        else:
+            lst.insert(i, obj)
+
+    def _setCommand(self, cmdObj):
+        # Add an attribute on this version object.  We need this to provide a
+        # way for clients to access the command objects.  We also need to strip
+        # off the version part from the front of the name.
+        if cmdObj.__class__.__name__.find("_") != -1:
+            name = cmdObj.__class__.__name__.split("_", 1)[1]
+        else:
+            name = cmdObj.__class__.__name__.lower()
+
+        setattr(self, name.lower(), cmdObj)
+
+        # Also, add the object into the _writeOrder dict in the right place.
+        if cmdObj.writePriority is not None:
+            if cmdObj.writePriority in self._writeOrder:
+                self._insertSorted(self._writeOrder[cmdObj.writePriority], cmdObj)
+            else:
+                self._writeOrder[cmdObj.writePriority] = [cmdObj]
+
+    def registerCommand(self, cmdName, cmdClass):
+        # First make sure we haven't instantiated this command handler
+        # already.  If we have, we just need to make another mapping to
+        # it in self.commands.
+        # NOTE:  We can't use the resetCommand method here since that relies
+        # upon cmdClass already being instantiated.  We'll just have to keep
+        # these two code blocks in sync.
+        cmdObj = None
+
+        for (_key, val) in list(self.commands.items()):
+            if val.__class__.__name__ == cmdClass.__name__:
+                cmdObj = val
+                break
+
+        # If we didn't find an instance in self.commands, create one now.
+        if cmdObj is None:
+            cmdObj = cmdClass()
+            self._setCommand(cmdObj)
+
+        # Finally, add the mapping to the commands dict.
+        self.commands[cmdName] = cmdObj
+        self.commands[cmdName].handler = self
+
+    def registerData(self, dataName, dataClass):
+        # We also need to create attributes for the various data objects.
+        setattr(self, dataName, dataClass)
+
+    def resetCommand(self, cmdName):
+        """Given the name of a command that's already been instantiated, create
+           a new instance of it that will take the place of the existing
+           instance.  This is equivalent to quickly blanking out all the
+           attributes that were previously set.
+
+           This method raises a KeyError if cmdName is invalid.
+        """
+        if cmdName not in self.commands:
+            raise KeyError
+
+        cmdObj = self.commands[cmdName].__class__()
+
+        self._setCommand(cmdObj)
+        self.commands[cmdName] = cmdObj
+        self.commands[cmdName].handler = self
+
+    def dispatcher(self, args, lineno):
+        """Call the appropriate KickstartCommand handler for the current line
+           in the kickstart file.  A handler for the current command should
+           be registered, though a handler of None is not an error.  Returns
+           the data object returned by KickstartCommand.parse.
+
+           args    -- A list of arguments to the current command
+           lineno  -- The line number in the file, for error reporting
+        """
+        cmd = args[0]
+
+        if cmd not in self.commands:
+            raise KickstartParseError(_("Unknown command: %s") % cmd, lineno=lineno)
+        elif self.commands[cmd] is not None:
+            self.commands[cmd].currentCmd = cmd
+            self.commands[cmd].currentLine = self.currentLine
+            self.commands[cmd].lineno = lineno
+            self.commands[cmd].seen = True
+
+            # The parser returns the data object that was modified.  This is either
+            # the command handler object itself (a KickstartCommand object), or it's
+            # a BaseData subclass instance that should be put into the command's
+            # dataList.  The latter is done via side effects.
+            #
+            # Regardless, return the object that was given to us by the parser.
+            obj = self.commands[cmd].parse(args[1:])
+
+            # Here's the side effect part - don't worry about lst not being returned.
+            lst = self.commands[cmd].dataList()
+            if isinstance(obj, BaseData) and lst is not None:
+                lst.append(obj)
+
+            return obj
+
+
+class BaseHandler(KickstartHandler):
+    """A base kickstart handler.
+
+       Each version of kickstart syntax is provided by a subclass of this
+       class. These subclasses are what users will interact with for parsing,
+       extracting data, and writing out kickstart files.  This is an abstract
+       class.
+    """
+
     def __init__(self, mapping=None, dataMapping=None, commandUpdates=None,
                  dataUpdates=None, *args, **kwargs):
         """Create a new BaseHandler instance.  This method must be provided by
@@ -226,28 +462,21 @@ class BaseHandler(KickstartObject):
 
            Instance attributes:
 
-           commands -- A mapping from a string command to a KickstartCommand
-                       subclass object that handles it.  Multiple strings can
-                       map to the same object, but only one instance of the
-                       command object should ever exist.  Most users should
-                       never have to deal with this directly, as it is
-                       manipulated internally and called through dispatcher.
-           currentLine -- The current unprocessed line from the input file
-                          that caused this handler to be run.
            packages -- An instance of pykickstart.parser.Packages which
                        describes the packages section of the input file.
            platform -- A string describing the hardware platform, which is
                        needed only by system-config-kickstart.
            scripts  -- A list of pykickstart.parser.Script instances, which is
                        populated by KickstartParser.addScript and describes the
-                       %pre/%post/%traceback script section of the input file.
+                       %pre/%pre-install/%post/%traceback script section of the
+                       input file.
         """
 
         # We don't want people using this class by itself.
         if self.__class__ is BaseHandler:
-            raise TypeError ("BaseHandler is an abstract class.")
+            raise TypeError("BaseHandler is an abstract class.")
 
-        KickstartObject.__init__(self, *args, **kwargs)
+        KickstartHandler.__init__(self, *args, **kwargs)
 
         # This isn't really a good place for these, but it's better than
         # everything else I can think of.
@@ -256,153 +485,69 @@ class BaseHandler(KickstartObject):
         self.tpk_packages = TpkPackages()
         self.platform = ""
 
-        # These will be set by the dispatcher.
-        self.commands = {}
-        self.currentLine = 0
-
-        # A dict keyed by an integer priority number, with each value being a
-        # list of KickstartCommand subclasses.  This dict is maintained by
-        # registerCommand and used in __str__.  No one else should be touching
-        # it.
-        self._writeOrder = {}
+        # Any sections that we do not understand but want to prevent causing errors
+        # are represented by a NullSection.  We want to preserve those on output, so
+        # keep a list of their string representations here.  This is likely to change
+        # in the future.  Don't rely on this exact implementation.
+        self._null_section_strings = []
 
         self._registerCommands(mapping, dataMapping, commandUpdates, dataUpdates)
 
     def __str__(self):
         """Return a string formatted for output to a kickstart file."""
-        retval = ""
+        retval = "# Generated by pykickstart v%s\n" % __version__
 
-        if self.platform != "":
+        if self.platform:
             retval += "#platform=%s\n" % self.platform
 
         retval += "#version=%s\n" % versionToString(self.version)
 
-        lst = self._writeOrder.keys()
-        lst.sort()
-
-        for prio in lst:
-            for obj in self._writeOrder[prio]:
-                retval += obj.__str__()
+        retval += KickstartHandler.__str__(self)
 
         for script in self.scripts:
             retval += script.__str__()
 
+        if self._null_section_strings:
+            retval += "\n"
+
+            for s in self._null_section_strings:
+                retval += s
+
         retval += self.packages.__str__()
 
         return retval
 
-    def _insertSorted(self, lst, obj):
-        length = len(lst)
-        i = 0
-
-        while i < length:
-            # If the two classes have the same name, it's because we are
-            # overriding an existing class with one from a later kickstart
-            # version, so remove the old one in favor of the new one.
-            if obj.__class__.__name__ > lst[i].__class__.__name__:
-                i += 1
-            elif obj.__class__.__name__ == lst[i].__class__.__name__:
-                lst[i] = obj
-                return
-            elif obj.__class__.__name__ < lst[i].__class__.__name__:
-                break
-
-        if i >= length:
-            lst.append(obj)
-        else:
-            lst.insert(i, obj)
-
-    def _setCommand(self, cmdObj):
-        # Add an attribute on this version object.  We need this to provide a
-        # way for clients to access the command objects.  We also need to strip
-        # off the version part from the front of the name.
-        if cmdObj.__class__.__name__.find("_") != -1:
-            name = unicode(cmdObj.__class__.__name__.split("_", 1)[1])
-        else:
-            name = unicode(cmdObj.__class__.__name__).lower()
-
-        setattr(self, name.lower(), cmdObj)
-
-        # Also, add the object into the _writeOrder dict in the right place.
-        if cmdObj.writePriority is not None:
-            if self._writeOrder.has_key(cmdObj.writePriority):
-                self._insertSorted(self._writeOrder[cmdObj.writePriority], cmdObj)
-            else:
-                self._writeOrder[cmdObj.writePriority] = [cmdObj]
-
     def _registerCommands(self, mapping=None, dataMapping=None, commandUpdates=None,
                           dataUpdates=None):
-        if mapping == {} or mapping == None:
+        if mapping == {} or mapping is None:
             from pykickstart.handlers.control import commandMap
             cMap = commandMap[self.version]
         else:
             cMap = mapping
 
-        if dataMapping == {} or dataMapping == None:
+        if dataMapping == {} or dataMapping is None:
             from pykickstart.handlers.control import dataMap
             dMap = dataMap[self.version]
         else:
             dMap = dataMapping
 
-        if type(commandUpdates) == types.DictType:
+        # Apply the command and data updates, but do
+        # not modify the original command and data maps.
+        if isinstance(commandUpdates, dict):
+            cMap = dict(cMap)
             cMap.update(commandUpdates)
 
-        if type(dataUpdates) == types.DictType:
+        if isinstance(dataUpdates, dict):
+            dMap = dict(dMap)
             dMap.update(dataUpdates)
 
-        for (cmdName, cmdClass) in cMap.iteritems():
-            # First make sure we haven't instantiated this command handler
-            # already.  If we have, we just need to make another mapping to
-            # it in self.commands.
-            cmdObj = None
+        for (cmdName, cmdClass) in list(cMap.items()):
+            self.registerCommand(cmdName, cmdClass)
 
-            for (key, val) in self.commands.iteritems():
-                if val.__class__.__name__ == cmdClass.__name__:
-                    cmdObj = val
-                    break
-
-            # If we didn't find an instance in self.commands, create one now.
-            if cmdObj == None:
-                cmdObj = cmdClass()
-                self._setCommand(cmdObj)
-
-            # Finally, add the mapping to the commands dict.
-            self.commands[cmdName] = cmdObj
-            self.commands[cmdName].handler = self
-
-        # We also need to create attributes for the various data objects.
         # No checks here because dMap is a bijection.  At least, that's what
         # the comment says.  Hope no one screws that up.
-        for (dataName, dataClass) in dMap.iteritems():
-            setattr(self, dataName, dataClass)
-
-    def dispatcher(self, args, lineno):
-        """Call the appropriate KickstartCommand handler for the current line
-           in the kickstart file.  A handler for the current command should
-           be registered, though a handler of None is not an error.  Returns
-           the data object returned by KickstartCommand.parse.
-
-           args    -- A list of arguments to the current command
-           lineno  -- The line number in the file, for error reporting
-        """
-        cmd = args[0]
-
-        if not self.commands.has_key(cmd):
-            raise KickstartParseError (formatErrorMsg(lineno, msg=_("Unknown command: %s" % cmd)))
-        elif self.commands[cmd] != None:
-            self.commands[cmd].currentCmd = cmd
-            self.commands[cmd].currentLine = self.currentLine
-            self.commands[cmd].lineno = lineno
-
-            # The parser returns the data object that was modified.  This could
-            # be a BaseData subclass that should be put into a list, or it
-            # could be the command handler object itself.
-            obj = self.commands[cmd].parse(args[1:])
-            lst = self.commands[cmd].dataList()
-            if lst is not None:
-                lst.append(obj)
-
-            return obj
+        for (dataName, dataClass) in list(dMap.items()):
+            self.registerData(dataName, dataClass)
 
     def maskAllExcept(self, lst):
         """Set all entries in the commands dict to None, except the ones in
@@ -410,15 +555,14 @@ class BaseHandler(KickstartObject):
         """
         self._writeOrder = {}
 
-        for (key, val) in self.commands.iteritems():
-            if not key in lst:
+        for (key, _val) in list(self.commands.items()):
+            if key not in lst:
                 self.commands[key] = None
 
     def hasCommand(self, cmd):
         """Return true if there is a handler for the string cmd."""
         return hasattr(self, cmd)
 
-
 ###
 ### DATA
 ###
@@ -430,16 +574,21 @@ class BaseData(KickstartObject):
     def __init__(self, *args, **kwargs):
         """Create a new BaseData instance.
 
-        lineno -- Line number in the ks-file where this object was defined
+           lineno -- Line number in the ks-file where this object was defined
         """
 
         # We don't want people using this class by itself.
         if self.__class__ is BaseData:
-            raise TypeError ("BaseData is an abstract class.")
+            raise TypeError("BaseData is an abstract class.")
 
         KickstartObject.__init__(self, *args, **kwargs)
         self.lineno = 0
 
+        # If a subclass provides a removedKeywords list, warn if the user
+        # continues to use some of the removed keywords
+        for arg in (kw for kw in self.removedKeywords if kw in kwargs):
+            warnings.warn("The '%s' keyword has been removed." % arg, KickstartParseWarning, stacklevel=2)
+
     def __str__(self):
         """Return a string formatted for output to a kickstart file."""
         return ""
@@ -449,7 +598,7 @@ class BaseData(KickstartObject):
            keyword arguments.  Valid attributes are anything specified in a
            subclass, but unknown attributes will be ignored.
         """
-        for (key, val) in kwargs.items():
+        for (key, val) in list(kwargs.items()):
             # Ignore setting attributes that were removed in a subclass, as
             # if they were unknown attributes.
             if key in self.removedAttrs:
@@ -463,5 +612,5 @@ class BaseData(KickstartObject):
            list.  This method should be called from __init__ in a subclass,
            but only after the superclass's __init__ method has been called.
         """
-        for attr in filter(lambda k: hasattr(self, k), self.removedAttrs):
+        for attr in [k for k in self.removedAttrs if hasattr(self, k)]:
             delattr(self, attr)
