@@ -160,6 +160,32 @@ def _do_lzop(input_name, compression=True):
 
     return output_name
 
+def _do_zstd(input_name, compression=True):
+    """ Compress/decompress the file with 'zstd' utility.
+
+    @input_name: the file name to compress/decompress
+    @compress: True for compressing, False for decompressing
+    @retval: the path of the compressed/decompressed file
+    """
+    if which("zstd") is  None:
+        msger.error("zstd is not in mic-bootstrap, please add zstd to mic-bootstrap")
+
+    compressor = "zstd"
+
+    if compression:
+        cmdln = [compressor,"--rm",  "-f",  input_name]
+    else:
+        cmdln = [compressor, "--rm", "-d", "-f", input_name]
+
+    _call_external(cmdln)
+
+    if compression:
+        output_name = input_name + ".zst"
+    else:
+        output_name = os.path.splitext(input_name)[0]
+
+    return output_name
+
 _COMPRESS_SUFFIXES = {
     ".lzo"     : [".lzo"],
     ".gz"      : [".gz"],
@@ -180,7 +206,7 @@ def get_compress_formats():
 
     @retval: a list contained supported compress formats
     """
-    return _COMPRESS_FORMATS.keys()
+    return list(_COMPRESS_FORMATS.keys())
 
 def get_compress_suffixes():
     """ Get the list of the support suffixes
@@ -188,7 +214,7 @@ def get_compress_suffixes():
     @retval: a list contained all suffixes
     """
     suffixes = []
-    for key in _COMPRESS_SUFFIXES.keys():
+    for key in list(_COMPRESS_SUFFIXES.keys()):
         suffix = _COMPRESS_SUFFIXES[key]
         if (suffix):
             suffixes.extend(suffix)
@@ -222,7 +248,7 @@ def decompress(file_path, decompress_format=None):
         raise OSError ("can't decompress a file not existed: '%s'" % file_path)
 
     (file_name, file_ext) = os.path.splitext(file_path)
-    for key, suffixes in _COMPRESS_SUFFIXES.iteritems():
+    for key, suffixes in list(_COMPRESS_SUFFIXES.items()):
         if file_ext in suffixes:
             file_ext = key
             break
@@ -356,12 +382,14 @@ def _make_zipfile(archive_name, target_name):
 
     return os.path.exists(archive_name)
 
+
 _ARCHIVE_SUFFIXES = {
     "zip"   : [".zip"],
     "tar"   : [".tar"],
     "lzotar": [".tzo", ".tar.lzo"],
     "gztar" : [".tgz", ".taz", ".tar.gz"],
     "bztar" : [".tbz", ".tbz2", ".tar.bz", ".tar.bz2"],
+    "zsttar": [".tar.zst"],
 }
 
 _ARCHIVE_FORMATS = {
@@ -370,6 +398,7 @@ _ARCHIVE_FORMATS = {
     "lzotar": ( _make_tarball, {"compressor" : _do_lzop} ),
     "gztar" : ( _make_tarball, {"compressor" : _do_gzip} ),
     "bztar" : ( _make_tarball, {"compressor" : _do_bzip2} ),
+    "zsttar" : ( _make_tarball, {"compressor" : _do_zstd} ),
 }
 
 def get_archive_formats():
@@ -377,7 +406,7 @@ def get_archive_formats():
 
     @retval: a list contained archive formats
     """
-    return _ARCHIVE_FORMATS.keys()
+    return list(_ARCHIVE_FORMATS.keys())
 
 def get_archive_suffixes():
     """ Get the list of the support suffixes
@@ -385,7 +414,7 @@ def get_archive_suffixes():
     @retval: a list contained all suffixes
     """
     suffixes = []
-    for name in _ARCHIVE_FORMATS.keys():
+    for name in list(_ARCHIVE_FORMATS.keys()):
         suffix = _ARCHIVE_SUFFIXES.get(name, None)
         if (suffix):
             suffixes.extend(suffix)
@@ -402,8 +431,8 @@ def make_archive(archive_name, target_name):
     if not os.path.exists(target_name):
         raise OSError ("archive object does not exist: '%s'" % target_name)
 
-    for aformat, suffixes in _ARCHIVE_SUFFIXES.iteritems():
-        if filter(archive_name.endswith, suffixes):
+    for aformat, suffixes in list(_ARCHIVE_SUFFIXES.items()):
+        if list(filter(archive_name.endswith, suffixes)):
             archive_format = aformat
             break
     else:
