@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/usr/bin/python3 -tt
 #
 # Copyright (c) 2009, 2010, 2011 Intel, Inc.
 #
@@ -15,7 +15,7 @@
 # with this program; if not, write to the Free Software Foundation, Inc., 59
 # Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-from __future__ import with_statement
+
 import os
 import sys
 import tempfile
@@ -30,6 +30,7 @@ from mic.utils import errors, proxy, misc
 from mic.utils.rpmmisc import readRpmHeader, RPMInstallCallback
 from mic.chroot import cleanup_mounts, setup_chrootenv, cleanup_chrootenv
 from mic.conf import configmgr
+from functools import reduce
 
 PATH_BOOTSTRAP = "/usr/sbin:/usr/bin:/sbin:/bin"
 
@@ -114,10 +115,10 @@ class MiniBackend(object):
         if not self.scriptlets:
             return
 
-        for pkg in self.preins.keys():
+        for pkg in list(self.preins.keys()):
             prog, script = self.preins[pkg]
             self.run_pkg_script(pkg, prog, script, '0')
-        for pkg in self.postins.keys():
+        for pkg in list(self.postins.keys()):
             prog, script = self.postins[pkg]
             self.run_pkg_script(pkg, prog, script, '1')
 
@@ -141,7 +142,7 @@ class MiniBackend(object):
                                         ','.join(nonexist))
 
     def installPkgs(self):
-        for pkg in self.localpkgs.keys():
+        for pkg in list(self.localpkgs.keys()):
             rpmpath = self.localpkgs[pkg]
 
             hdr = readRpmHeader(self.ts, rpmpath)
@@ -178,7 +179,7 @@ class MiniBackend(object):
             os.makedirs(tmpdir)
         tmpfd, tmpfp = tempfile.mkstemp(dir=tmpdir, prefix="%s.pre-" % pkg)
         script = script.replace('\r', '')
-        os.write(tmpfd, script)
+        os.write(tmpfd, script.encode())
         os.close(tmpfd)
         os.chmod(tmpfp, 0o700)
 
@@ -237,7 +238,7 @@ class Bootstrap(object):
             pkgmgr.arch = self.arch
             pkgmgr.repomd = repomd
             pkgmgr.optionals = list(optlist)
-            map(pkgmgr.selectPackage, pkglist + list(optlist))
+            list(map(pkgmgr.selectPackage, pkglist + list(optlist)))
             pkgmgr.runInstall()
         except (OSError, IOError, errors.CreatorError) as err:
             raise errors.BootstrapError("%s" % err)
