@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/usr/bin/python3 -tt
 #
 # Copyright (c) 2009, 2010, 2011 Intel, Inc.
 #
@@ -15,7 +15,7 @@
 # with this program; if not, write to the Free Software Foundation, Inc., 59
 # Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-from __future__ import with_statement
+
 import os
 import re
 import shutil
@@ -65,7 +65,7 @@ def ELF_arch(chrootdir):
             continue
 
         outs = runner.outs(['file', cpath])
-        for ptn in mapping.keys():
+        for ptn in list(mapping.keys()):
             if re.search(ptn, outs):
                 return mapping[ptn]
 
@@ -281,7 +281,7 @@ def savefs_before_chroot(chrootdir, saveto = None):
                     'dev/stderr',
                     'etc/mtab']
             ignlst = [os.path.join(saveto, x) for x in devs]
-            map(os.unlink, filter(os.path.exists, ignlst))
+            list(map(os.unlink, list(filter(os.path.exists, ignlst))))
         else:
             msger.warning(wrnmsg)
 
