@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/usr/bin/python3 -tt
 # vim: ai ts=4 sts=4 et sw=4
 #
 # Copyright (c) 2012 Intel, Inc.
@@ -57,7 +57,7 @@ def main(parser, args, argv):
         imagetype = "loop"
 
     chrootclass = None
-    for pname, pcls in pluginmgr.get_plugins('imager').iteritems():
+    for pname, pcls in list(pluginmgr.get_plugins('imager').items()):
         if pname == imagetype and hasattr(pcls, "do_chroot"):
             chrootclass = pcls
             break
@@ -67,5 +67,3 @@ def main(parser, args, argv):
                                   % imagetype)
 
     chrootclass.do_chroot(targetimage, args.cmd)
-        
-    
