@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/usr/bin/python3 -tt
 # vim: ai ts=4 sts=4 et sw=4
 #
 # Copyright (c) 2012 Intel, Inc.
@@ -82,9 +82,10 @@ def main(parser, args, argv):
             rpm.setVerbosity(rpm.RPMLOG_DEBUG)
         except ImportError:
             pass
+
     #check the imager type
     createrClass = None
-    for subcmd, klass in pluginmgr.get_plugins('imager').iteritems():
+    for subcmd, klass in list(pluginmgr.get_plugins('imager').items()):
         if subcmd == args.subcommand and hasattr(klass, 'do_create'):
             createrClass = klass
 
@@ -135,7 +136,7 @@ def main(parser, args, argv):
     if args.strict_mode:
       configmgr.create['strict_mode'] = args.strict_mode
     if args.arch is not None:
-        supported_arch = sorted(rpmmisc.archPolicies.keys(), reverse=True)
+        supported_arch = sorted(list(rpmmisc.archPolicies.keys()), reverse=True)
         if args.arch in supported_arch:
             configmgr.create['arch'] = args.arch
         else:
@@ -149,10 +150,12 @@ def main(parser, args, argv):
 
     if args.skip_set_hosts:
         configmgr.create['skip_set_hosts']=args.skip_set_hosts
+
     if args.postscripts_maxruntime:
         configmgr.create['postscripts_maxruntime']=int(args.postscripts_maxruntime)
     if args.block_recommends:
         configmgr.create['block_recommends']=args.block_recommends
+
     if args.runtime:
         configmgr.set_runtime(args.runtime)
 
@@ -228,9 +231,9 @@ def do_auto(parser, ksfile, argv):
 
             inline_argv = m.group(1).strip()
             if ptype == 'mic':
-                m2 = re.search('(?P<format>\w+)', inline_argv)
+                m2 = re.search(r'(?P<format>\w+)', inline_argv)
             elif ptype == 'mic2':
-                m2 = re.search('(-f|--format(=)?)\s*(?P<format>\w+)',
+                m2 = re.search(r'(-f|--format(=)?)\s*(?P<format>\w+)',
                                inline_argv)
             else:
                 return None
@@ -248,8 +251,8 @@ def do_auto(parser, ksfile, argv):
         with open(ksfile, 'r') as rf:
             first_line = rf.readline()
 
-        mic_re = '^#\s*-\*-mic-options-\*-\s+(.*)\s+-\*-mic-options-\*-'
-        mic2_re = '^#\s*-\*-mic2-options-\*-\s+(.*)\s+-\*-mic2-options-\*-'
+        mic_re = r'^#\s*-\*-mic-options-\*-\s+(.*)\s+-\*-mic-options-\*-'
+        mic2_re = r'^#\s*-\*-mic2-options-\*-\s+(.*)\s+-\*-mic2-options-\*-'
 
         result = parse_magic_line(mic_re, first_line, 'mic') \
                  or parse_magic_line(mic2_re, first_line, 'mic2')
@@ -267,4 +270,3 @@ def do_auto(parser, ksfile, argv):
         args = parser.parse_args(options)
 
         main(parser, args, options)
-
