@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/usr/bin/python3 -tt
 #
 # Copyright (c) 2011 Intel, Inc.
 #
@@ -16,7 +16,7 @@
 # Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
 import os, sys, re
-import ConfigParser
+import configparser
 
 from mic import msger
 from mic import kickstart
@@ -122,14 +122,14 @@ class ConfigMgr(object):
         self.__siteconf = None
 
         # initialize the values with defaults
-        for sec, vals in self.DEFAULTS.iteritems():
+        for sec, vals in list(self.DEFAULTS.items()):
             setattr(self, sec, vals)
 
     def __set_siteconf(self, siteconf):
         try:
             self.__siteconf = siteconf
             self._parse_siteconf(siteconf)
-        except ConfigParser.Error as error:
+        except configparser.Error as error:
             raise errors.ConfigError("%s" % error)
     def __get_siteconf(self):
         return self.__siteconf
@@ -157,13 +157,13 @@ class ConfigMgr(object):
         if not siteconf:
             self.common["distro_name"] = "Tizen"
             # append common section items to other sections
-            for section in self.DEFAULTS.keys():
+            for section in list(self.DEFAULTS.keys()):
                 if section != "common":
                     getattr(self, section).update(self.common)
 
             return
 
-        parser = ConfigParser.SafeConfigParser()
+        parser = configparser.ConfigParser()
         parser.read(siteconf)
 
         for section in parser.sections():
@@ -171,13 +171,13 @@ class ConfigMgr(object):
                 getattr(self, section).update(dict(parser.items(section)))
 
         # append common section items to other sections
-        for section in self.DEFAULTS.keys():
+        for section in list(self.DEFAULTS.keys()):
             if section != "common":
                 getattr(self, section).update(self.common)
 
         # check and normalize the scheme of proxy url
         if self.create['proxy']:
-            m = re.match('^(\w+)://.*', self.create['proxy'])
+            m = re.match(r'^(\w+)://.*', self.create['proxy'])
             if m:
                 scheme = m.group(1)
                 if scheme not in ('http', 'https', 'ftp', 'socks'):
@@ -191,7 +191,7 @@ class ConfigMgr(object):
 
         # bootstrap option handling
         self.set_runtime(self.create['runtime'])
-        if isinstance(self.bootstrap['packages'], basestring):
+        if isinstance(self.bootstrap['packages'], str):
             packages = self.bootstrap['packages'].replace('\n', ' ')
             if packages.find(',') != -1:
                 packages = packages.split(',')
