@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/usr/bin/python3 -tt
 #
 # Copyright (c) 2007 Red Hat  Inc.
 # Copyright (c) 2009, 2010, 2011 Intel, Inc.
@@ -16,8 +16,9 @@
 # with this program; if not, write to the Free Software Foundation, Inc., 59
 # Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-from __future__ import with_statement
-import os, sys
+
+import os
+import sys
 import stat
 import tempfile
 import shutil
@@ -58,7 +59,7 @@ class BaseImageCreator(object):
     def __del__(self):
         self.cleanup()
 
-    def __init__(self, createopts = None, pkgmgr = None):
+    def __init__(self, createopts=None, pkgmgr=None):
         """Initialize an ImageCreator instance.
 
         ks -- a pykickstart.KickstartParser instance; this instance will be
@@ -97,15 +98,15 @@ class BaseImageCreator(object):
 
         if createopts:
             # Mapping table for variables that have different names.
-            optmap = {"pkgmgr" : "pkgmgr_name",
-                      "arch" : "target_arch",
-                      "local_pkgs_path" : "_local_pkgs_path",
-                      "copy_kernel" : "_need_copy_kernel",
-                      "strict_mode" : "strict_mode",
-                     }
+            optmap = {"pkgmgr": "pkgmgr_name",
+                      "arch": "target_arch",
+                      "local_pkgs_path": "_local_pkgs_path",
+                      "copy_kernel": "_need_copy_kernel",
+                      "strict_mode": "strict_mode",
+                      }
 
             # update setting from createopts
-            for key in createopts.keys():
+            for key in list(createopts.keys()):
                 if key in optmap:
                     option = optmap[key]
                 else:
@@ -116,7 +117,7 @@ class BaseImageCreator(object):
 
             if self.pack_to:
                 (tar, ext) = os.path.splitext(self.pack_to)
-                if ext in (".gz", ".bz2", ".lzo", ".bz") and tar.endswith(".tar"):
+                if ext in (".gz", ".bz2", ".lzo", ".bz", ".zst") and tar.endswith(".tar"):
                     ext = ".tar" + ext
                 if ext not in get_archive_suffixes():
                     self.pack_to += ".tar"
@@ -157,10 +158,11 @@ class BaseImageCreator(object):
                     self._dep_checks.append("mkfs.btrfs")
                     continue
                 if part.cpioopts:
-                    if part.fstype == "cpio": 
+                    if part.fstype == "cpio":
                         part.fstype = "ext4"
                     else:
-                        raise KsError("The '--fstype' in ks file need to set 'cpio' when you want to generate image by cpio.")
+                        raise KsError(
+                            "The '--fstype' in ks file need to set 'cpio' when you want to generate image by cpio.")
             if len(self.ks.handler.partition.partitions) > 1:
                 self.multiple_partitions = True
 
@@ -175,15 +177,15 @@ class BaseImageCreator(object):
                     self._dep_checks.append("qemu-arm-static")
 
                 if os.path.exists("/proc/sys/vm/vdso_enabled"):
-                    vdso_fh = open("/proc/sys/vm/vdso_enabled","r")
+                    vdso_fh = open("/proc/sys/vm/vdso_enabled", "r")
                     vdso_value = vdso_fh.read().strip()
                     vdso_fh.close()
                     if (int)(vdso_value) == 1:
                         msger.warning("vdso is enabled on your host, which might "
-                            "cause problems with arm emulations.\n"
-                            "\tYou can disable vdso with following command before "
-                            "starting image build:\n"
-                            "\techo 0 | sudo tee /proc/sys/vm/vdso_enabled")
+                                      "cause problems with arm emulations.\n"
+                                      "\tYou can disable vdso with following command before "
+                                      "starting image build:\n"
+                                      "\techo 0 | sudo tee /proc/sys/vm/vdso_enabled")
             elif self.target_arch == "mipsel":
                 for dep in self._dep_checks:
                     if dep == "extlinux":
@@ -194,7 +196,7 @@ class BaseImageCreator(object):
                     self._dep_checks.append("qemu-mipsel-static")
 
                 if os.path.exists("/proc/sys/vm/vdso_enabled"):
-                    vdso_fh = open("/proc/sys/vm/vdso_enabled","r")
+                    vdso_fh = open("/proc/sys/vm/vdso_enabled", "r")
                     vdso_value = vdso_fh.read().strip()
                     vdso_fh.close()
                     if (int)(vdso_value) == 1:
@@ -229,10 +231,10 @@ class BaseImageCreator(object):
         if not os.path.exists(self.cachedir):
             os.makedirs(self.cachedir)
 
-
     #
     # Properties
     #
+
     def __get_instroot(self):
         if self.__builddir is None:
             raise CreatorError("_instroot is not valid before calling mount()")
@@ -266,11 +268,10 @@ class BaseImageCreator(object):
 
     """
 
-
     #
     # Hooks for subclasses
     #
-    def _mount_instroot(self, base_on = None):
+    def _mount_instroot(self, base_on=None):
         """Mount or prepare the install root directory.
 
         This is the hook where subclasses may prepare the install root by e.g.
@@ -325,20 +326,21 @@ class BaseImageCreator(object):
         shutil.move(self._instroot, self._outdir + "/" + self.name)
 
     def get_installed_packages(self):
-        return self._pkgs_content.keys()
+        return list(self._pkgs_content.keys())
 
     def _save_recording_pkgs(self, destdir):
         """Save the list or content of installed packages to file.
         """
-        pkgs = self._pkgs_content.keys()
-        pkgs.sort() # inplace op
+        pkgs = list(self._pkgs_content.keys())
+        pkgs.sort()  # inplace op
 
         if not os.path.exists(destdir):
             os.makedirs(destdir)
 
         content = None
         if 'vcs' in self._recording_pkgs:
-            vcslst = ["%s %s" % (k, v) for (k, v) in self._pkgs_vcsinfo.items()]
+            vcslst = ["%s %s" % (k, v)
+                      for (k, v) in list(self._pkgs_vcsinfo.items())]
             content = '\n'.join(sorted(vcslst))
         elif 'name' in self._recording_pkgs:
             content = '\n'.join(pkgs)
@@ -372,14 +374,12 @@ class BaseImageCreator(object):
             f = open(licensefile, "w")
 
             f.write('Summary:\n')
-            for license in reversed(sorted(self._pkgs_license, key=\
-                            lambda license: len(self._pkgs_license[license]))):
-                f.write("    - %s: %s\n" \
+            for license in reversed(sorted(self._pkgs_license, key=lambda license: len(self._pkgs_license[license]))):
+                f.write("    - %s: %s\n"
                         % (license, len(self._pkgs_license[license])))
 
             f.write('\nDetails:\n')
-            for license in reversed(sorted(self._pkgs_license, key=\
-                            lambda license: len(self._pkgs_license[license]))):
+            for license in reversed(sorted(self._pkgs_license, key=lambda license: len(self._pkgs_license[license]))):
                 f.write("    - %s:\n" % (license))
                 for pkg in sorted(self._pkgs_license[license]):
                     f.write("        - %s\n" % (pkg))
@@ -431,7 +431,7 @@ class BaseImageCreator(object):
         if self._local_pkgs_path:
             if os.path.isdir(self._local_pkgs_path):
                 return glob.glob(
-                        os.path.join(self._local_pkgs_path, '*.rpm'))
+                    os.path.join(self._local_pkgs_path, '*.rpm'))
             elif os.path.splitext(self._local_pkgs_path)[-1] == '.rpm':
                 return [self._local_pkgs_path]
 
@@ -446,9 +446,9 @@ class BaseImageCreator(object):
         A sensible default implementation is provided.
 
         """
-        s =  "/dev/root  /         %s    %s 0 0\n" \
-             % (self._fstype,
-                "defaults,noatime" if not self._fsopts else self._fsopts)
+        s = "/dev/root  /         %s    %s 0 0\n" \
+            % (self._fstype,
+               "defaults,noatime" if not self._fsopts else self._fsopts)
         s += self._get_fstab_special()
         return s
 
@@ -476,7 +476,7 @@ class BaseImageCreator(object):
             value = str(value)
 
         name = self.installerfw_prefix + ("PART%d_" % pnum) + prop
-        return { name : value }
+        return {name: value}
 
     def _get_post_scripts_env(self, in_chroot):
         """Return an environment dict for %post scripts.
@@ -600,10 +600,10 @@ class BaseImageCreator(object):
 
         return ret
 
-
     #
     # Helpers for subclasses
     #
+
     def _do_bindmounts(self):
         """Mount various system directories onto _instroot.
 
@@ -640,7 +640,7 @@ class BaseImageCreator(object):
         os.chroot(self._instroot)
         os.chdir("/")
 
-    def _mkdtemp(self, prefix = "tmp-"):
+    def _mkdtemp(self, prefix="tmp-"):
         """Create a temporary directory.
 
         This method may be used by subclasses to create a temporary directory
@@ -659,9 +659,9 @@ class BaseImageCreator(object):
 
         """
         self.__ensure_builddir()
-        return tempfile.mkdtemp(dir = self.__builddir, prefix = prefix)
+        return tempfile.mkdtemp(dir=self.__builddir, prefix=prefix)
 
-    def _mkstemp(self, prefix = "tmp-"):
+    def _mkstemp(self, prefix="tmp-"):
         """Create a temporary file.
 
         This method may be used by subclasses to create a temporary file
@@ -681,9 +681,9 @@ class BaseImageCreator(object):
 
         """
         self.__ensure_builddir()
-        return tempfile.mkstemp(dir = self.__builddir, prefix = prefix)
+        return tempfile.mkstemp(dir=self.__builddir, prefix=prefix)
 
-    def _mktemp(self, prefix = "tmp-"):
+    def _mktemp(self, prefix="tmp-"):
         """Create a temporary file.
 
         This method simply calls _mkstemp() and closes the returned file
@@ -702,10 +702,10 @@ class BaseImageCreator(object):
         os.close(f)
         return path
 
-
     #
     # Actual implementation
     #
+
     def __ensure_builddir(self):
         if not self.__builddir is None:
             return
@@ -714,13 +714,13 @@ class BaseImageCreator(object):
             self.workdir = os.path.join(self.tmpdir, "build")
             if not os.path.exists(self.workdir):
                 os.makedirs(self.workdir)
-            self.__builddir = tempfile.mkdtemp(dir = self.workdir,
-                                               prefix = "imgcreate-")
+            self.__builddir = tempfile.mkdtemp(dir=self.workdir,
+                                               prefix="imgcreate-")
         except OSError as msg:
             raise CreatorError("Failed create build directory in %s: %s" %
                                (self.tmpdir, msg))
 
-    def get_cachedir(self, cachedir = None):
+    def get_cachedir(self, cachedir=None):
         if self.cachedir:
             return self.cachedir
 
@@ -758,7 +758,7 @@ class BaseImageCreator(object):
         """Create a minimal /dev so that we don't corrupt the host /dev"""
         origumask = os.umask(0000)
         devices = (('null',   1, 3, 0o666),
-                   ('urandom',1, 9, 0o666),
+                   ('urandom', 1, 9, 0o666),
                    ('random', 1, 8, 0o666),
                    ('full',   1, 7, 0o666),
                    ('ptmx',   5, 2, 0o666),
@@ -774,7 +774,7 @@ class BaseImageCreator(object):
             if not os.path.exists(self._instroot + "/dev/" + node):
                 os.mknod(self._instroot + "/dev/" + node,
                          perm | stat.S_IFCHR,
-                         os.makedev(major,minor))
+                         os.makedev(major, minor))
 
         for (src, dest) in links:
             if not os.path.exists(self._instroot + dest):
@@ -795,7 +795,7 @@ class BaseImageCreator(object):
         runner.show('umount -l %s' % self.workdir)
 
     def cp_tpk(self):
-        #Add tpk-install option
+        # Add tpk-install option
         createopts = configmgr.create
         if createopts['tpk_install']:
             path = createopts['tpk_install']
@@ -803,15 +803,16 @@ class BaseImageCreator(object):
             for f in file_list:
                 sub = os.path.splitext(f)[1]
                 if sub != ".tpk":
-                    raise CreatorError("Not all files in the path: "+path +" is tpk")
+                    raise CreatorError(
+                        "Not all files in the path: "+path + " is tpk")
 
             tpk_dir = "/usr/apps/.preload-tpk"
             fs.makedirs(self._instroot + "/usr/apps")
             fs.makedirs(self._instroot + tpk_dir)
             for f in file_list:
-                shutil.copy(path+"/"+f,self._instroot + tpk_dir)
+                shutil.copy(path+"/"+f, self._instroot + tpk_dir)
 
-    def mount(self, base_on = None, cachedir = None):
+    def mount(self, base_on=None, cachedir=None):
         """Setup the target filesystem in preparation for an install.
 
         This function sets up the filesystem which the ImageCreator will
@@ -852,7 +853,7 @@ class BaseImageCreator(object):
         if self.target_arch and self.target_arch.startswith("arm") or \
             self.target_arch == "aarch64" or self.target_arch == "riscv64":
             self.qemu_emulators = misc.setup_qemu_emulator(self._instroot,
-                                                          self.target_arch)
+                                                           self.target_arch)
 
         self.get_cachedir(cachedir)
 
@@ -862,8 +863,8 @@ class BaseImageCreator(object):
                           ("/proc/sys/fs/binfmt_misc", None),
                           ("/dev/pts", None)]:
             self.__bindmounts.append(
-                    fs.BindChrootMount(
-                        f, self._instroot, dest))
+                fs.BindChrootMount(
+                    f, self._instroot, dest))
 
         self._do_bindmounts()
 
@@ -873,7 +874,7 @@ class BaseImageCreator(object):
             os.unlink(self._instroot + "/etc/mtab")
         os.symlink("../proc/mounts", self._instroot + "/etc/mtab")
 
-        #self.__write_fstab()
+        # self.__write_fstab()
 
         # get size of available space in 'instroot' fs
         self._root_fs_avail = misc.get_filesystem_avail(self._instroot)
@@ -903,10 +904,10 @@ class BaseImageCreator(object):
         try:
             instroot_pdir = os.path.dirname(self._instroot + self._instroot)
             if os.path.exists(instroot_pdir):
-                shutil.rmtree(instroot_pdir, ignore_errors = True)
+                shutil.rmtree(instroot_pdir, ignore_errors=True)
             yumlibdir = self._instroot + "/var/lib/yum"
             if os.path.exists(yumlibdir):
-                shutil.rmtree(yumlibdir, ignore_errors = True)
+                shutil.rmtree(yumlibdir, ignore_errors=True)
         except OSError:
             pass
 
@@ -915,7 +916,6 @@ class BaseImageCreator(object):
         # reset settings of popup dialog in Ubuntu(s)
         misc.unhide_loopdev_presentation()
 
-
     def cleanup(self):
         """Unmounts the target filesystem and deletes temporary files.
 
@@ -940,7 +940,7 @@ class BaseImageCreator(object):
 
         self.unmount()
 
-        shutil.rmtree(self.__builddir, ignore_errors = True)
+        shutil.rmtree(self.__builddir, ignore_errors=True)
         self.__builddir = None
 
         self.__clean_tmpdir()
@@ -1071,7 +1071,7 @@ class BaseImageCreator(object):
                         return True
                     else:
                         continue
-             
+
             return False
 
         def showErrorInfo(filepath):
@@ -1111,7 +1111,6 @@ class BaseImageCreator(object):
             if 'debuginfo' in self.install_pkgs:
                 pkg_manager.install_debuginfo = True
 
-
         for repo in kickstart.get_repos(self.ks, repo_urls, self.ignore_ksrepo):
             (name, baseurl, mirrorlist, inc, exc,
              proxy, proxy_username, proxy_password, debuginfo,
@@ -1120,8 +1119,8 @@ class BaseImageCreator(object):
 
             ssl_verify = get_ssl_verify(ssl_verify)
             yr = pkg_manager.addRepository(name, baseurl, mirrorlist, proxy,
-                        proxy_username, proxy_password, inc, exc, ssl_verify,
-                        nocache, cost, priority)
+                                           proxy_username, proxy_password, inc, exc, ssl_verify,
+                                           nocache, cost, priority)
 
         if kickstart.exclude_docs(self.ks):
             rpm.addMacro("_excludedocs", "1")
@@ -1135,10 +1134,10 @@ class BaseImageCreator(object):
             self.__select_packages(pkg_manager)
             self.__select_groups(pkg_manager)
             self.__deselect_packages(pkg_manager)
-            #self.__localinst_packages(pkg_manager)
+            # self.__localinst_packages(pkg_manager)
             self.__check_packages(pkg_manager)
 
-            BOOT_SAFEGUARD = 256 * 1024 * 1024 # 256M
+            BOOT_SAFEGUARD = 256 * 1024 * 1024  # 256M
             checksize = self._root_fs_avail
             if checksize:
                 checksize -= BOOT_SAFEGUARD
@@ -1152,7 +1151,7 @@ class BaseImageCreator(object):
             pkg_manager.runInstall(checksize)
         except CreatorError as e:
             raise
-        except  KeyboardInterrupt:
+        except KeyboardInterrupt:
             raise
         else:
             self._pkgs_content = pkg_manager.getAllContent()
@@ -1165,7 +1164,7 @@ class BaseImageCreator(object):
         if checkScriptletError(self._instroot + "/tmp/.postscript/error/", "_error"):
             showErrorInfo(self._instroot + "/tmp/.preload_install_error")
             raise CreatorError('scriptlet errors occurred')
-            
+
         # hook post install
         self.postinstall()
 
@@ -1189,28 +1188,30 @@ class BaseImageCreator(object):
             for pkg in tpk_pkgs:
                 flag = 0
                 for tpk_repo in tpk_repoList:
-                    if hasattr(tpk_repo,'baseurl') and tpk_repo.baseurl.startswith("file:"):
-                        tpk_repourl = tpk_repo.baseurl.replace('file:','')
+                    if hasattr(tpk_repo, 'baseurl') and tpk_repo.baseurl.startswith("file:"):
+                        tpk_repourl = tpk_repo.baseurl.replace('file:', '')
                         tpk_repourl = "/%s" % tpk_repourl.lstrip('/')
-                        tpk_pkgpath = tpk_repourl + "/"+ pkg
+                        tpk_pkgpath = tpk_repourl + "/" + pkg
                         if os.path.isfile(tpk_pkgpath):
-                            shutil.copy(tpk_pkgpath,self._instroot + tpk_dir)
+                            shutil.copy(tpk_pkgpath, self._instroot + tpk_dir)
                             flag = 1
                             break
-                    elif hasattr(tpk_repo,'baseurl'):
+                    elif hasattr(tpk_repo, 'baseurl'):
                         url = tpk_repo.baseurl.join(pkg)
                         filename = self._instroot+tpk_dir+"/"+pkg
                         if tpk_repo.baseurl.startswith("http:"):
-                            import urllib
-                            status = urllib.urlopen(url).code
+                            import urllib.request
+                            import urllib.parse
+                            import urllib.error
+                            status = urllib.request.urlopen(url).code
                             if status == 200:
                                 filename = myurlgrab(url.full, filename, None)
                                 flag = 1
                                 break
                             elif status == 404 or status == None:
                                 continue
-                        #url is ok, then download, url wrong, check other url.
-                        elif tpk_repo.baseurl.startswith("https:") :
+                        # url is ok, then download, url wrong, check other url.
+                        elif tpk_repo.baseurl.startswith("https:"):
                             try:
                                 flag = 1
                                 filename = myurlgrab(url.full, filename, None)
@@ -1252,20 +1253,20 @@ class BaseImageCreator(object):
         return env
 
     def run_sign_scripts(self):
-        if kickstart.get_sign_scripts(self.ks)==[]:
+        if kickstart.get_sign_scripts(self.ks) == []:
             return
         msger.info("Running sign scripts ...")
         if os.path.exists(self._instroot + "/tmp"):
             shutil.rmtree(self._instroot + "/tmp")
-        os.mkdir (self._instroot + "/tmp", 0o755)
+        os.mkdir(self._instroot + "/tmp", 0o755)
         for s in kickstart.get_sign_scripts(self.ks):
-            (fd, path) = tempfile.mkstemp(prefix = "ks-runscript-",
-                                          dir = self._instroot + "/tmp")
+            (fd, path) = tempfile.mkstemp(prefix="ks-runscript-",
+                                          dir=self._instroot + "/tmp")
             s.script = s.script.replace("\r", "")
-            os.write(fd, s.script)
+            os.write(fd, s.script.encode())
             if s.interp == '/bin/sh' or s.interp == '/bin/bash':
-                os.write(fd, '\n')
-                os.write(fd, 'exit 0\n')
+                os.write(fd, '\n'.encode())
+                os.write(fd, 'exit 0\n'.encode())
             os.close(fd)
             os.chmod(path, 0o700)
 
@@ -1275,11 +1276,11 @@ class BaseImageCreator(object):
             try:
                 try:
                     p = subprocess.Popen([s.interp, path],
-                                       env = env,
-                                       stdout = subprocess.PIPE,
-                                       stderr = subprocess.STDOUT)
+                                         env=env,
+                                         stdout=subprocess.PIPE,
+                                         stderr=subprocess.STDOUT)
                     while p.poll() == None:
-                        msger.info(p.stdout.readline().strip())
+                        msger.info(p.stdout.readline().strip().decode())
                     if p.returncode != 0:
                         raise CreatorError("Failed to execute %%sign script "
                                            "with '%s'" % (s.interp))
@@ -1294,16 +1295,16 @@ class BaseImageCreator(object):
         msger.info("Running post scripts ...")
         if os.path.exists(self._instroot + "/tmp"):
             shutil.rmtree(self._instroot + "/tmp")
-        os.mkdir (self._instroot + "/tmp", 0o755)
+        os.mkdir(self._instroot + "/tmp", 0o755)
         for s in kickstart.get_post_scripts(self.ks):
-            (fd, path) = tempfile.mkstemp(prefix = "ks-postscript-",
-                                          dir = self._instroot + "/tmp")
+            (fd, path) = tempfile.mkstemp(prefix="ks-postscript-",
+                                          dir=self._instroot + "/tmp")
 
             s.script = s.script.replace("\r", "")
-            os.write(fd, s.script)
+            os.write(fd, s.script.encode())
             if s.interp == '/bin/sh' or s.interp == '/bin/bash':
-                os.write(fd, '\n')
-                os.write(fd, 'exit 0\n')
+                os.write(fd, '\n'.encode())
+                os.write(fd, 'exit 0\n'.encode())
             os.close(fd)
             os.chmod(path, 0o700)
 
@@ -1326,12 +1327,12 @@ class BaseImageCreator(object):
             try:
                 try:
                     p = subprocess.Popen([s.interp, script],
-                                       preexec_fn = preexec,
-                                       env = env,
-                                       stdout = subprocess.PIPE,
-                                       stderr = subprocess.STDOUT)
+                                         preexec_fn=preexec,
+                                         env=env,
+                                         stdout=subprocess.PIPE,
+                                         stderr=subprocess.STDOUT)
                     while p.poll() == None:
-                    	msger.info(p.stdout.readline().strip())
+                        msger.info(p.stdout.readline().strip().decode())
                         end_time = time.time()
                         if (end_time - start_time)/60 > configmgr.create['postscripts_maxruntime']:
                             raise CreatorError("Your post script is executed more than %d mins, please check it!" % configmgr.create['postscripts_maxruntime'])
@@ -1352,10 +1353,10 @@ class BaseImageCreator(object):
         fs.makedirs(self._instroot + gpgkeydir)
         for repo in repodata:
             if repo["repokey"]:
-                repokey = gpgkeydir + "/RPM-GPG-KEY-%s" %  repo["name"]
+                repokey = gpgkeydir + "/RPM-GPG-KEY-%s" % repo["name"]
                 shutil.copy(repo["repokey"], self._instroot + repokey)
 
-    def configure(self, repodata = None):
+    def configure(self, repodata=None):
         """Configure the system image according to the kickstart.
 
         This method applies the (e.g. keyboard or network) configuration
@@ -1372,7 +1373,7 @@ class BaseImageCreator(object):
             kickstart.LanguageConfig(self._instroot).apply(ksh.lang)
             kickstart.KeyboardConfig(self._instroot).apply(ksh.keyboard)
             kickstart.TimezoneConfig(self._instroot).apply(ksh.timezone)
-            #kickstart.AuthConfig(self._instroot).apply(ksh.authconfig)
+            # kickstart.AuthConfig(self._instroot).apply(ksh.authconfig)
             kickstart.FirewallConfig(self._instroot).apply(ksh.firewall)
             kickstart.UserConfig(self._instroot).apply(ksh.user)
             kickstart.RootPasswordConfig(self._instroot).apply(ksh.rootpw)
@@ -1382,7 +1383,8 @@ class BaseImageCreator(object):
             kickstart.RPMMacroConfig(self._instroot).apply(self.ks)
             kickstart.DesktopConfig(self._instroot).apply(ksh.desktop)
             self.__save_repo_keys(repodata)
-            kickstart.MoblinRepoConfig(self._instroot).apply(ksh.repo, repodata, self.repourl)
+            kickstart.MoblinRepoConfig(self._instroot).apply(
+                ksh.repo, repodata, self.repourl)
         except:
             msger.warning("Failed to apply configuration to image")
             raise
@@ -1399,7 +1401,7 @@ class BaseImageCreator(object):
         """
         if launch:
             msger.info("Launching shell. Exit to continue.")
-            subprocess.call(["/bin/bash"], preexec_fn = self._chroot)
+            subprocess.call(["/bin/bash"], preexec_fn=self._chroot)
 
     def do_genchecksum(self, image_name):
         if not self._genchecksum:
@@ -1434,9 +1436,11 @@ class BaseImageCreator(object):
                     cpiocmd = fs.find_binary_path('cpio')
                     if cpiocmd:
                         oldoutdir = os.getcwd()
-                        os.chdir(os.path.join(self._instroot, item['mountpoint'].lstrip('/')))
+                        os.chdir(os.path.join(self._instroot,
+                                              item['mountpoint'].lstrip('/')))
                         # find . | cpio --create --'format=newc' | gzip > ../ramdisk.img
-                        runner.show('find . | cpio --create %s | gzip > %s' % (item['cpioopts'], tmp_cpio_imgfile))
+                        runner.show('find . | cpio --create %s | gzip > %s' %
+                                    (item['cpioopts'], tmp_cpio_imgfile))
                         os.chdir(oldoutdir)
                 except OSError as msg:
                     raise CreatorError("Create image by cpio error: %s" % msg)
@@ -1445,16 +1449,18 @@ class BaseImageCreator(object):
         for item in self._instloops:
             if item['cpioopts']:
                 tmp_cpio = self.__builddir + "/tmp-cpio"
-                msger.info("Copy cpio image from %s to %s." %(tmp_cpio, self._imgdir))
+                msger.info("Copy cpio image from %s to %s." %
+                           (tmp_cpio, self._imgdir))
                 try:
-                    shutil.copyfile(os.path.join(tmp_cpio, item['name']),os.path.join(self._imgdir, item['name']))
+                    shutil.copyfile(os.path.join(tmp_cpio, item['name']), os.path.join(
+                        self._imgdir, item['name']))
                 except IOError:
                     raise CreatorError("Copy cpio image error")
                 os.remove(os.path.join(tmp_cpio, item['name']))
                 if not os.listdir(tmp_cpio):
                     shutil.rmtree(tmp_cpio, ignore_errors=True)
 
-    def package(self, destdir = "."):
+    def package(self, destdir="."):
         """Prepares the created image for final delivery.
 
         In its simplest form, this method merely copies the install root to the
@@ -1479,7 +1485,7 @@ class BaseImageCreator(object):
         # For image formats with two or multiple image files, it will be
         # better to put them under a directory
         if self.image_format in ("raw", "vmdk", "vdi", "nand", "mrstnand"):
-            destdir = os.path.join(destdir, "%s-%s" \
+            destdir = os.path.join(destdir, "%s-%s"
                                             % (self.name, self.image_format))
             msger.debug("creating destination dir: %s" % destdir)
             fs.makedirs(destdir)
@@ -1506,14 +1512,14 @@ class BaseImageCreator(object):
         for tool in self._dep_checks:
             fs.find_binary_path(tool)
 
-    def package_output(self, image_format, destdir = ".", package="none"):
+    def package_output(self, image_format, destdir=".", package="none"):
         if not package or package == "none":
             return
 
         destdir = os.path.abspath(os.path.expanduser(destdir))
         (pkg, comp) = os.path.splitext(package)
         if comp:
-            comp=comp.lstrip(".")
+            comp = comp.lstrip(".")
 
         if pkg == "tar":
             if comp:
@@ -1529,11 +1535,11 @@ class BaseImageCreator(object):
             for file in self.outimage:
                 msger.info("adding %s to %s" % (file, dst))
                 tar.add(file,
-                        arcname=os.path.join("%s-%s" \
-                                           % (self.name, image_format),
-                                              os.path.basename(file)))
+                        arcname=os.path.join("%s-%s"
+                                             % (self.name, image_format),
+                                             os.path.basename(file)))
                 if os.path.isdir(file):
-                    shutil.rmtree(file, ignore_errors = True)
+                    shutil.rmtree(file, ignore_errors=True)
                 else:
                     os.remove(file)
 
@@ -1595,12 +1601,12 @@ class BaseImageCreator(object):
             outimages.append("%s/%s" % (destdir, hash_name))
 
         hash_dict = {
-                     'MD5SUMS'    : misc.get_md5sum,
-                     'SHA1SUMS'   : misc.get_sha1sum,
-                     'SHA256SUMS' : misc.get_sha256sum
-                    }
+            'MD5SUMS': misc.get_md5sum,
+            'SHA1SUMS': misc.get_sha1sum,
+            'SHA256SUMS': misc.get_sha256sum
+        }
 
-        for k, v in hash_dict.items():
+        for k, v in list(hash_dict.items()):
             generate_hashsum(k, v)
 
         # Filter out the nonexist file
@@ -1635,10 +1641,10 @@ class BaseImageCreator(object):
         pass
 
     def get_pkg_manager(self):
-        return self.pkgmgr(target_arch = self.target_arch,
-                           instroot = self._instroot,
-                           cachedir = self.cachedir,
-                           strict_mode = self.strict_mode)
+        return self.pkgmgr(target_arch=self.target_arch,
+                           instroot=self._instroot,
+                           cachedir=self.cachedir,
+                           strict_mode=self.strict_mode)
 
     def create_manifest(self):
         def get_pack_suffix():
