@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/usr/bin/python3 -tt
 #
 # Copyright (c) 2013 Intel, Inc.
 #
@@ -18,6 +18,9 @@
 from pykickstart.base import *
 from pykickstart.options import *
 from mic import msger
+from pykickstart.version import DEVEL
+
+from pykickstart.i18n import _
 
 class Mic_installerfw(KickstartCommand):
     """ This class implements the "installerfw_plugins" KS option. The argument
@@ -49,17 +52,20 @@ class Mic_installerfw(KickstartCommand):
         return retval
 
     def _getParser(self):
-        op = KSOptionParser()
+        op = KSOptionParser(prog='installerfw', description='installerfw', version=DEVEL)
         return op
 
     def parse(self, args):
-        (_, extra) = self.op.parse_args(args=args, lineno=self.lineno)
+        print("NNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNN")
+        (ns, extra) = self.op.parse_known_args(args=args, lineno=self.lineno)
+        self.set_to_self(ns)
 
         if len(extra) != 1:
-            msg = "Kickstart command \"%s\" requires one " \
-                  "argumet - a list of legacy features to disable" % self.currentCmd
-            raise KickstartValueError  (formatErrorMsg(self.lineno, msg = msg))
-
-        self.features = extra[0].split(",")
+            raise KickstartParseError(_("Kickstart command %s requires one argument") % "installerfw", lineno=self.lineno)
+        elif any(arg for arg in extra if arg.startswith("-")):
+            mapping = {"command": "installerfw", "options": extra}
+            raise KickstartParseError(_("Unexpected arguments to %(command)s command: %(options)s") % mapping, lineno=self.lineno)
+        else:
+            self.features = extra[0].split(",")
 
         return self
