@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/usr/bin/python3 -tt
 #
 # Marko Saukko <marko.saukko@cybercom.com>
 #
@@ -77,27 +77,27 @@ class Mic_Partition(FC4_Partition):
         op = FC4_Partition._getParser(self)
         # The alignment value is given in kBytes. e.g., value 8 means that
         # the partition is aligned to start from 8096 byte boundary.
-        op.add_option("--align", type="int", action="store", dest="align",
-                      default=None)
-        op.add_option("--extoptions", type="string", action="store", dest="extopts",
-                      default=None)
-        op.add_option("--f2fsoptions", type="string", action="store", dest="f2fsopts",
-                      default=None)
-        op.add_option("--part-type", type="string", action="store", dest="part_type",
-                      default=None)
-        op.add_option("--uuid", dest="uuid", action="store", type="string")
-        op.add_option("--exclude-from-image", action="store_true", dest="exclude_image",
-                      default=False)
-        op.add_option("--vdfsoptions", type="string", action="store", dest="vdfsopts",
-                      default=None)
-        op.add_option("--squashfsoptions", type="string", action="store", dest="squashfsopts",
-                      default=None)
-        op.add_option("--squashfsoptions_maxsize", type="string", action="store", dest="squashfsoptions_maxsize",
-                      default=None)
-        op.add_option("--erofsoptions", type="string", action="store", dest="erofsopts",
-                      default=None)
-        op.add_option("--cpiooptions", type="string", action="store", dest="cpioopts",
-                      default=None)
-        op.add_option("--no-shrink", action="store_true", dest="no_shrink", default=False)
-        op.add_option("--init-expand", action="store_true", dest="init_expand", default=False)
+        op.add_argument("--align", type=int, action="store", dest="align",
+                      default=None, version=FC4, help='align')
+        op.add_argument("--extoptions", type=str, action="store", dest="extopts",
+                      default=None, version=FC4, help='extoptions')
+        op.add_argument("--f2fsoptions", type=str, action="store", dest="f2fsopts",
+                      default=None, version=FC4, help='f2fsoptions')
+        op.add_argument("--part-type", type=str, action="store", dest="part_type",
+                      default=None, version=FC4, help='part-type')
+        op.add_argument("--uuid", dest="uuid", action="store", type=str, version=FC4, help='uuid')
+        op.add_argument("--exclude-from-image", action="store_true", dest="exclude_image",
+                      default=False, version=FC4, help='exclude-from-image')
+        op.add_argument("--vdfsoptions", type=str, action="store", dest="vdfsopts",
+                      default=None, version=FC4, help='vdfsoptions')
+        op.add_argument("--squashfsoptions", type=str, action="store", dest="squashfsopts",
+                      default=None, version=FC4, help='squashfsoptions')
+        op.add_argument("--squashfsoptions_maxsize", type=str, action="store", dest="squashfsoptions_maxsize",
+                       default=None, version=FC4, help='squashfsoptions_maxsiz')
+        op.add_argument("--erofsoptions", type=str, action="store", dest="erofsopts",
+                      default=None, version=FC4, help='erofsoptions')
+        op.add_argument("--cpiooptions", type=str, action="store", dest="cpioopts",
+                      default=None, version=FC4, help='cpiooptions')
+        op.add_argument("--no-shrink", action="store_true", dest="no_shrink", default=False, version=FC4, help='no-shrink')
+        op.add_argument("--init-expand", action="store_true", dest="init_expand", default=False, version=FC4, help='init-expand')
         return op
