@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/usr/bin/python3 -tt
 #
 # Copyright (c) 2009, 2010, 2011 Intel, Inc.
 #
@@ -27,7 +27,7 @@ import ctypes
 from mic import bootstrap, msger, kickstart
 from mic.conf import configmgr
 from mic.utils import errors, proxy
-from mic.utils.fs_related import find_binary_path, makedirs
+from mic.utils.fs_related import find_binary_path, makedirs, load_module
 from mic.chroot import setup_chrootenv, cleanup_chrootenv, ELF_arch
 
 from mic.plugin import pluginmgr
@@ -87,12 +87,12 @@ def run_scripts_out_bootstrap(ks, rundir, env=None):
 
     msger.info("Running scripts out bootstrap ...")
     for s in kickstart.get_out_bootstarp_scripts(ks):
-        (fd, path) = tempfile.mkstemp(prefix = "ks-runscript-out-bootstrap-")
+        (fd, path) = tempfile.mkstemp(prefix="ks-runscript-out-bootstrap-")
         s.script = s.script.replace("\r", "")
-        os.write(fd, s.script)
+        os.write(fd, s.script.encode())
         if s.interp == '/bin/sh' or s.interp == '/bin/bash':
-            os.write(fd, '\n')
-            os.write(fd, 'exit 0\n')
+            os.write(fd, '\n'.encode())
+            os.write(fd, 'exit 0\n'.encode())
         os.close(fd)
         os.chmod(path, 0o700)
 
@@ -106,7 +106,7 @@ def run_scripts_out_bootstrap(ks, rundir, env=None):
                                      stdout = subprocess.PIPE,
                                      stderr = subprocess.STDOUT)
                 while p.poll() == None:
-                    msger.info(p.stdout.readline().strip())
+                    msger.info(p.stdout.readline().strip().decode())
                 if p.returncode != 0:
                     raise errors.CreatorError("Failed to execute script out bootstrap "
                                               "with '%s'" % (s.interp))
@@ -147,6 +147,13 @@ def bootstrap_mic(argv=None):
     else:
         optlist = []
 
+    #For Ubuntu 24.04, the kernel module is compressed with zstd, but the modprobe binary in tizen bootstrap
+    #don't support zstd compression. Need to load needed kernel module on host PC firstly.
+    for part in sorted(kickstart.get_partitions(cropts['ks']),
+                               key=lambda p: p.mountpoint):
+        if part.fstype == "btrfs" or part.fstype == "f2fs":
+            load_module(part.fstype)
+
     try:
         msger.info("Creating %s bootstrap ..." % distro)
         bsenv.create(cropts['repomd'], pkglist, optlist)
@@ -156,12 +163,16 @@ def bootstrap_mic(argv=None):
             rootdir = os.path.join(rootdir, "bootstrap")
 
         bsenv.dirsetup(rootdir)
-        #when mic in mic-bootstrap is py3, use mic version in mic-bootstrap.
-        if cropts['use_mic_in_bootstrap'] | (mic_py2_in_mic_bootstrap(os.path.join(rootdir, '/usr/bin/mic'.lstrip('/'))) == False):
+        if cropts['use_mic_in_bootstrap']:
             msger.info("No copy host mic")
         else:
-            msger.info("Copy host mic to bootstrap")
-            sync_mic(rootdir, plugin=cropts['plugin_dir'])
+            #when mic in mic-bootstrap is py2, use mic version in mic-bootstrap.
+            if (mic_py2_in_mic_bootstrap(os.path.join(rootdir, '/usr/bin/mic'.lstrip('/'))) == True):
+                msger.info("Copy host mic conf to bootstrap")
+                sync_mic_conf(rootdir)
+            else:
+                msger.info("Copy host mic to bootstrap")
+                sync_mic(rootdir, plugin=cropts['plugin_dir'])
 
         #FIXME: sync the ks file to bootstrap
         if "/" == os.path.dirname(os.path.abspath(configmgr._ksconf)):
@@ -206,8 +217,8 @@ def get_bindmounts(cropts):
     for ltpkrepo in cropts['localtpkrepos']:
         binddirs.append(ltpkrepo)
 
-    bindlist = map(expath, filter(None, binddirs))
-    bindlist += map(os.path.dirname, map(expath, filter(None, bindfiles)))
+    bindlist = list(map(expath, [_f for _f in binddirs if _f]))
+    bindlist += list(map(os.path.dirname, list(map(expath, [_f for _f in bindfiles if _f]))))
     bindlist = sorted(set(bindlist))
     bindmounts = ';'.join(bindlist)
     return bindmounts
@@ -248,11 +259,26 @@ def get_mic_modpath():
 def get_mic_libpath():
     return os.getenv("MIC_LIBRARY_PATH", "/usr/lib/mic")
 
+def sync_mic_conf(bootstrap, conf = '/etc/mic/mic.conf'):
+    _path = lambda p: os.path.join(bootstrap, p.lstrip('/'))
+
+    try:
+        safecopy(conf, _path(conf), False)
+    except (OSError, IOError) as err:
+        raise errors.BootstrapError(err)
+
+    # auto select backend
+    with open(_path(conf), 'r') as rf:
+        conf_str = rf.read()
+    conf_str = re.sub(r"pkgmgr\s*=\s*.*", "pkgmgr=auto", conf_str)
+    with open(_path(conf), 'w') as wf:
+        wf.write(conf_str)
+
 # the hard code path is prepared for bootstrap
 def sync_mic(bootstrap, binpth = '/usr/bin/mic',
              libpth='/usr/lib',
              plugin='/usr/lib/mic/plugins',
-             pylib = '/usr/lib/python2.7/site-packages',
+             pylib = '/usr/lib/python3/site-packages',
              conf = '/etc/mic/mic.conf'):
     _path = lambda p: os.path.join(bootstrap, p.lstrip('/'))
 
@@ -265,7 +291,7 @@ def sync_mic(bootstrap, binpth = '/usr/bin/mic',
                }
 
     if not os.path.exists(_path(pylib)):
-        pyptn = '/usr/lib/python?.?/site-packages'
+        pyptn = '/usr/lib/python3.*/site-packages'
         pylibs = glob.glob(_path(pyptn))
         if pylibs:
             pylib = pylibs[0].replace(bootstrap, '')
@@ -273,28 +299,22 @@ def sync_mic(bootstrap, binpth = '/usr/bin/mic',
             raise errors.BootstrapError("Can't find python site dir in: %s" %
                                         bootstrap)
 
-    for key, value in micpaths.items():
+    for key, value in list(micpaths.items()):
         try:
             safecopy(value, _path(eval(key)), False, ["*.pyc", "*.pyo"])
         except (OSError, IOError) as err:
             raise errors.BootstrapError(err)
 
     # auto select backend
-    conf_str = file(_path(conf)).read()
-    conf_str = re.sub("pkgmgr\s*=\s*.*", "pkgmgr=auto", conf_str)
+    with open(_path(conf), 'r') as rf:
+        conf_str = rf.read()
+    conf_str = re.sub(r"pkgmgr\s*=\s*.*", "pkgmgr=auto", conf_str)
     with open(_path(conf), 'w') as wf:
         wf.write(conf_str)
 
     # chmod +x /usr/bin/mic
     os.chmod(_path(binpth), 0o777)
 
-    # correct python interpreter
-    mic_cont = file(_path(binpth)).read()
-    mic_cont = "#!/usr/bin/python2\n" + mic_cont
-    with open(_path(binpth), 'w') as wf:
-        wf.write(mic_cont)
-
-
 def safecopy(src, dst, symlinks=False, ignore_ptns=()):
     if os.path.isdir(src):
         if os.path.isdir(dst):
@@ -358,7 +378,7 @@ def prepare_create(args):
                 pkgmgr = backends[key]
                 break
     else:
-        for key in backends.keys():
+        for key in list(backends.keys()):
             if key == creatoropts['pkgmgr']:
                 pkgmgr = backends[key]
                 break
@@ -367,6 +387,6 @@ def prepare_create(args):
         raise errors.CreatorError("Can't find backend: %s, "
                                   "available choices: %s" %
                                   (creatoropts['pkgmgr'],
-                                   ','.join(backends.keys())))
+                                   ','.join(list(backends.keys()))))
     return creatoropts, pkgmgr, recording_pkgs
 
