@@ -25,10 +25,14 @@ class CreatorError(Exception):
         self.msg = msg
 
     def __str__(self):
-        if isinstance(self.msg, unicode):
-            self.msg = self.msg.encode('utf-8', 'ignore')
+        if isinstance(self.msg, str):
+            pass
         else:
-            self.msg = str(self.msg)
+            try:
+                self.msg = self.msg.deocde()
+            except:
+                self.msg = str(self.msg)
+                pass
         return self.msg
 
     def __repr__(self):
