@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/usr/bin/python3 -tt
 #
 # Copyright (c) 2007, Red Hat, Inc.
 # Copyright (c) 2009, 2010, 2011 Intel, Inc.
@@ -16,7 +16,7 @@
 # with this program; if not, write to the Free Software Foundation, Inc., 59
 # Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-from __future__ import with_statement
+
 import os
 import re
 import sys
@@ -46,11 +46,11 @@ def find_binary_inchroot(binary, chroot):
     return None
 
 def find_binary_path(binary):
-    if os.environ.has_key("PATH"):
+    if "PATH" in os.environ:
         paths = os.environ["PATH"].split(":")
     else:
         paths = []
-        if os.environ.has_key("HOME"):
+        if "HOME" in os.environ:
             paths += [os.environ["HOME"] + "/bin"]
         paths += ["/usr/local/sbin", "/usr/local/bin", "/usr/sbin", "/usr/bin", "/sbin", "/bin"]
 
@@ -476,7 +476,7 @@ class F2fsDiskMount(DiskMount):
         found = False
         """ Need to load f2fs module to mount it """
         load_module("f2fs")
-        for line in open("/proc/filesystems").xreadlines():
+        for line in open("/proc/filesystems"):
             if line.find("f2fs") > -1:
                 found = True
                 break
@@ -499,7 +499,7 @@ class F2fsDiskMount(DiskMount):
 
         cmdlist = [self.mkfscmd, "-l", self.fslabel]
         if self.__f2fsopts:
-            cmdlist.extend(self.__f2fsopts.split())
+            cmdlist.extend(self._f2fsopts.split())
         cmdlist.extend([self.disk.device])
 
         rc, errout = runner.runtool(cmdlist, catch=2)
@@ -541,7 +541,7 @@ class F2fsDiskMount(DiskMount):
     def mount(self, options = None, init_expand = False):
         self.__create()
         if init_expand:
-            expand_size = long(self.disk.size * 1.5)
+            expand_size = int(self.disk.size * 1.5)
             msger.info("Initial partition size expanded : %ld -> %ld" % (self.disk.size, expand_size))
             self.__resize_filesystem(expand_size)
             self.disk.reread_size()
@@ -588,7 +588,7 @@ class ErofsDiskMount(DiskMount):
         found = False
         """ Need to load erofs module to mount it """
         load_module("erofs")
-        for line in open("/proc/filesystems").xreadlines():
+        for line in open("/proc/filesystems"):
             if line.find("erofs") > -1:
                 found = True
                 break
@@ -604,7 +604,6 @@ class ErofsDiskMount(DiskMount):
 
     def mount(self, options = None):
         """Mount an existing EROFS filesystem."""
-        
         if self.mounted:
             return
 
@@ -718,7 +717,7 @@ class ExtDiskMount(DiskMount):
     def mount(self, options = None, init_expand = False):
         self.__create()
         if init_expand:
-            expand_size = long(self.disk.size * 1.5)
+            expand_size = int(self.disk.size * 1.5)
             msger.info("Initial partition size expanded : %ld -> %ld" % (self.disk.size, expand_size))
             self.__resize_filesystem(expand_size)
             self.disk.reread_size()
@@ -807,7 +806,7 @@ class VfatDiskMount(DiskMount):
     def mount(self, options = None, init_expand = False):
         self.__create()
         if init_expand:
-            expand_size = long(self.disk.size * 1.5)
+            expand_size = int(self.disk.size * 1.5)
             msger.info("Initial partition size expanded : %ld -> %ld" % (self.disk.size, expand_size))
             self.__resize_filesystem(expand_size)
             self.disk.reread_size()
@@ -855,7 +854,7 @@ class BtrfsDiskMount(DiskMount):
         found = False
         """ Need to load btrfs module to mount it """
         load_module("btrfs")
-        for line in open("/proc/filesystems").xreadlines():
+        for line in open("/proc/filesystems"):
             if line.find("btrfs") > -1:
                 found = True
                 break
@@ -915,7 +914,7 @@ class BtrfsDiskMount(DiskMount):
     def mount(self, options = None, init_expand = False):
         self.__create()
         if init_expand:
-            expand_size = long(self.disk.size * 1.5)
+            expand_size = int(self.disk.size * 1.5)
             msger.info("Initial partition size expanded : %ld -> %ld" % (self.disk.size, expand_size))
             self.__resize_filesystem(expand_size)
             self.disk.reread_size()
@@ -1055,7 +1054,7 @@ def create_image_minimizer(path, image, minimal_size):
 
 def load_module(module):
     found = False
-    for line in open('/proc/modules').xreadlines():
+    for line in open('/proc/modules'):
         if line.startswith("%s " % module):
             found = True
             break
@@ -1086,8 +1085,7 @@ class LoopDevice(object):
             return 10
 
         fint = lambda x: x[9:].isdigit() and int(x[9:]) or 0
-        maxid = 1 + max(filter(lambda x: x<256,
-                               map(fint, glob.glob("/dev/loop[0-9]*"))))
+        maxid = 1 + max([x for x in map(fint, glob.glob("/dev/loop[0-9]*")) if x<256])
         if maxid < 10: maxid = 10
         if maxid >= 256:
             raise Exception("maxid >= 256")
@@ -1137,7 +1135,7 @@ class LoopDevice(object):
             try:
                 self.cleanup()
                 self.device = None
-            except MountError  as e:
+            except MountError as e:
                 raise CreatorError("%s" % e)
 
     def cleanup(self):
@@ -1232,4 +1230,3 @@ def clean_loop_devices(piddir=DEVICE_PIDFILE_DIR):
             os.unlink(pidfile)
         except:
             pass
-
