@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/usr/bin/python3 -tt
 #
 # Copyright (c) 2013 Intel, Inc.
 #
@@ -255,7 +255,7 @@ class GptParser:
         header = self.read_header(primary)
         raw_ptable = self._read_raw_ptable(header)
 
-        for index in xrange(0, header['entries_cnt']):
+        for index in range(0, header['entries_cnt']):
             start = header['entry_size'] * index
             end = start + header['entry_size']
             raw_entry = struct.unpack(_GPT_ENTRY_FORMAT, raw_ptable[start:end])
