@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/usr/bin/python3 -tt
 #
 # Copyright (c) 2010, 2011 Intel Inc.
 #
@@ -15,7 +15,7 @@
 # with this program; if not, write to the Free Software Foundation, Inc., 59
 # Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-from __future__ import with_statement
+
 import os
 import sys
 import time
@@ -27,7 +27,7 @@ import hashlib
 import subprocess
 import platform
 import traceback
-
+import distro
 
 try:
     import sqlite3 as sqlite
@@ -51,9 +51,9 @@ from mic.utils import rpmmisc
 from mic.utils.safeurl import SafeURL
 
 
-RPM_RE  = re.compile("(.*)\.(.*) (.*)-(.*)")
+RPM_RE  = re.compile(r"(.*)\.(.*) (.*)-(.*)")
 RPM_FMT = "%(name)s.%(arch)s %(version)s-%(release)s"
-SRPM_RE = re.compile("(.*)-(\d+.*)-(\d+\.\d+).src.rpm")
+SRPM_RE = re.compile(r"(.*)-(\d+.*)-(\d+\.\d+).src.rpm")
 
 
 def build_name(kscfg, release=None, prefix = None, suffix = None):
@@ -106,12 +106,8 @@ def get_distro():
                      'meego',
                      'moblin',
                      'tizen')
-    try:
-        (dist, ver, id) = platform.linux_distribution( \
-                              supported_dists = support_dists)
-    except:
-        (dist, ver, id) = platform.dist( \
-                              supported_dists = support_dists)
+    #platform.linux_distribution was removed in Python 3.8, use distro.linux_distribution(full_distribution_name=False) instead.
+    (dist, ver, id) = distro.linux_distribution(full_distribution_name=False)
 
     return (dist, ver, id)
 
@@ -184,7 +180,7 @@ def extract_rpm(rpmfile, targetdir):
                           stdout=subprocess.PIPE, stderr=subprocess.PIPE)
     p1.stdout.close()
     (sout, serr) = p2.communicate()
-    msger.verbose(sout or serr)
+    msger.verbose(sout.decode() or serr.decode())
 
     os.chdir(olddir)
 
@@ -294,7 +290,7 @@ def normalize_ksfile(ksconf, release, arch):
     ksc = ksc.replace("@BUILD_ID@", release)
 
     fd, ksconf = tempfile.mkstemp(prefix=os.path.basename(ksconf))
-    os.write(fd, ksc)
+    os.write(fd, ksc.encode())
     os.close(fd)
 
     msger.debug('normalized ks file:%s' % ksconf)
@@ -315,9 +311,9 @@ def _check_mic_chroot(rootdir):
     def _path(path):
         return rootdir.rstrip('/') + path
 
-    release_files = map(_path, [ "/etc/moblin-release",
+    release_files = list(map(_path, [ "/etc/moblin-release",
                                  "/etc/meego-release",
-                                 "/etc/tizen-release"])
+                                 "/etc/tizen-release"]))
 
     if not any(map(os.path.exists, release_files)):
         msger.warning("Dir %s is not a MeeGo/Tizen chroot env" % rootdir)
@@ -338,14 +334,14 @@ def selinux_check(arch, fstypes):
         raise CreatorError("Can't create arm image if selinux is enabled, "
                            "please run 'setenforce 0' to disable selinux")
 
-    use_btrfs = filter(lambda typ: typ == 'btrfs', fstypes)
+    use_btrfs = [typ for typ in fstypes if typ == 'btrfs']
     if use_btrfs and selinux_status == "Enforcing":
         raise CreatorError("Can't create btrfs image if selinux is enabled,"
                            " please run 'setenforce 0' to disable selinux")
 
 def get_image_type(path):
     def _get_extension_name(path):
-        match = re.search("(?<=\.)\w+$", path)
+        match = re.search(r"(?<=\.)\w+$", path)
         if match:
             return match.group(0)
         else:
@@ -568,14 +564,14 @@ def get_metadata_from_repos(repos, cachedir):
         checksums = {}
         sumtypes = {}
 
-        for elm in root.getiterator("%sdata" % ns):
+        for elm in root.iter("%sdata" % ns):
             if elm.attrib["type"] == "patterns":
                 filepaths['patterns'] = elm.find("%slocation" % ns).attrib['href']
                 checksums['patterns'] = elm.find("%sopen-checksum" % ns).text
                 sumtypes['patterns'] = elm.find("%sopen-checksum" % ns).attrib['type']
                 break
 
-        for elm in root.getiterator("%sdata" % ns):
+        for elm in root.iter("%sdata" % ns):
             #"group" type has no "open-checksum" filed, remove it.
             if elm.attrib["type"] == "group_gz":
                 filepaths['comps'] = elm.find("%slocation" % ns).attrib['href']
@@ -584,7 +580,7 @@ def get_metadata_from_repos(repos, cachedir):
                 break
 
         primary_type = None
-        for elm in root.getiterator("%sdata" % ns):
+        for elm in root.iter("%sdata" % ns):
             if elm.attrib["type"] in ("primary_db", "primary"):
                 primary_type = elm.attrib["type"]
                 filepaths['primary'] = elm.find("%slocation" % ns).attrib['href']
@@ -641,17 +637,17 @@ def get_rpmver_in_repo(repometadata):
             ns = ns[0:ns.rindex("}")+1]
 
             versionlist = []
-            for elm in root.getiterator("%spackage" % ns):
+            for elm in root.iter("%spackage" % ns):
                 if elm.find("%sname" % ns).text == 'rpm':
-                    for node in elm.getchildren():
+                    for node in list(elm):
                         if node.tag == "%sversion" % ns:
                             versionlist.append(node.attrib['ver'])
 
             if versionlist:
-                return reversed(
+                return next(reversed(
                          sorted(
                            versionlist,
-                           key = lambda ver: map(int, ver.split('.')))).next()
+                           key = lambda ver: list(map(int, ver.split('.'))))))
 
         elif repo["primary"].endswith(".sqlite"):
             con = sqlite.connect(repo["primary"])
@@ -669,7 +665,7 @@ def get_arch(repometadata):
             root = xmlparse(repo["primary"])
             ns = root.getroot().tag
             ns = ns[0:ns.rindex("}")+1]
-            for elm in root.getiterator("%spackage" % ns):
+            for elm in root.iter("%spackage" % ns):
                 if elm.find("%sarch" % ns).text not in ("noarch", "src"):
                     arch = elm.find("%sarch" % ns).text
                     if arch not in archlist:
@@ -684,7 +680,7 @@ def get_arch(repometadata):
 
     uniq_arch = []
     for i in range(len(archlist)):
-        if archlist[i] not in rpmmisc.archPolicies.keys():
+        if archlist[i] not in list(rpmmisc.archPolicies.keys()):
             continue
         need_append = True
         j = 0
@@ -722,7 +718,7 @@ def get_package(pkg, repometadata, arch = None):
             root = xmlparse(repo["primary"])
             ns = root.getroot().tag
             ns = ns[0:ns.rindex("}")+1]
-            for elm in root.getiterator("%spackage" % ns):
+            for elm in root.iter("%spackage" % ns):
                 if elm.find("%sname" % ns).text == pkg and elm.find("%sarch" % ns).text in arches:
                     if repo["priority"] != None:
                         tmpprior = int(repo["priority"])
@@ -810,7 +806,7 @@ def get_source_name(pkg, repometadata):
             root = xmlparse(repo["primary"])
             ns = root.getroot().tag
             ns = ns[0:ns.rindex("}")+1]
-            for elm in root.getiterator("%spackage" % ns):
+            for elm in root.iter("%spackage" % ns):
                 if elm.find("%sname" % ns).text == pkg_name:
                     if elm.find("%sarch" % ns).text != "src":
                         version = elm.find("%sversion" % ns)
@@ -819,7 +815,7 @@ def get_source_name(pkg, repometadata):
                             ver = tmpver
                             fmt = elm.find("%sformat" % ns)
                             if fmt:
-                                fns = fmt.getchildren()[0].tag
+                                fns = list(fmt)[0].tag
                                 fns = fns[0:fns.rindex("}")+1]
                                 pkgpath = fmt.find("%ssourcerpm" % fns).text
                                 target_repo = repo
@@ -883,7 +879,7 @@ def get_pkglist_in_comps(group, comps):
     except SyntaxError:
         raise SyntaxError("%s syntax error." % comps)
 
-    for elm in root.getiterator("group"):
+    for elm in root.iter("group"):
         id = elm.find("id")
         name = elm.find("name")
         if id.text == group or name.text == group:
@@ -894,7 +890,7 @@ def get_pkglist_in_comps(group, comps):
     if not found:
         return pkglist
 
-    for require in elm.getiterator("packagereq"):
+    for require in elm.iter("packagereq"):
         if require.tag.endswith("packagereq"):
             pkgname = require.text
         if pkgname not in pkglist:
@@ -956,7 +952,10 @@ def setup_qemu_emulator(rootdir, arch):
 
     # qemu_emulator is a special case, we can't use find_binary_path
     # qemu emulator should be a statically-linked executable file
-    arm_binary, node = get_qemu_arm_binary(arch)
+    try:
+        arm_binary, node = get_qemu_arm_binary(arch)
+    except CreatorError as err:
+        msger.error(err)
     qemu_emulator = "/usr/bin/%s" % arm_binary
 
     if not os.path.exists(rootdir + "/usr/bin"):
@@ -1035,7 +1034,7 @@ def SrcpkgsDownload(pkgs, repometadata, instroot, cachedir):
     for lpkg in lpkgs_path:
         lpkg_name = get_src_name(os.path.basename(lpkg))
         lpkgs_dict[lpkg_name] = lpkg
-    localpkgs = lpkgs_dict.keys()
+    localpkgs = list(lpkgs_dict.keys())
 
     cached_count = 0
     destdir = instroot+'/usr/src/SRPMS'
