@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/usr/bin/python3 -tt
 #
 # Copyright (c) 2009, 2010, 2011 Intel, Inc.
 # Copyright (c) 2007, 2008 Red Hat, Inc.
@@ -188,7 +188,7 @@ class PartitionedMount(Mount):
         for n in range(len(self.partitions)):
             p = self.partitions[n]
 
-            if not self.disks.has_key(p['disk_name']):
+            if p['disk_name'] not in self.disks:
                 raise MountError("No disk %s for partition %s" \
                                  % (p['disk_name'], p['mountpoint']))
 
@@ -263,7 +263,7 @@ class PartitionedMount(Mount):
 
         # Once all the partitions have been laid out, we can calculate the
         # minimum disk sizes.
-        for disk_name, d in self.disks.items():
+        for disk_name, d in list(self.disks.items()):
             d['min_size'] = d['offset']
             if d['ptable_format'] == 'gpt':
                 # Account for the backup partition table at the end of the disk
@@ -308,7 +308,7 @@ class PartitionedMount(Mount):
             msger.debug("Skipping disk format, because skipformat flag is set.")
             return
 
-        for dev in self.disks.keys():
+        for dev in list(self.disks.keys()):
             d = self.disks[dev]
             msger.debug("Initializing partition table for %s" % \
                         (d['disk'].device))
@@ -371,7 +371,7 @@ class PartitionedMount(Mount):
         # If the partition table format is "gpt", find out PARTUUIDs for all
         # the partitions. And if users specified custom parition type UUIDs,
         # set them.
-        for disk_name, disk in self.disks.items():
+        for disk_name, disk in list(self.disks.items()):
             if disk['ptable_format'] != 'gpt':
                 continue
 
@@ -403,7 +403,7 @@ class PartitionedMount(Mount):
         """Load it if dm_snapshot isn't loaded. """
         load_module("dm_snapshot")
 
-        for dev in self.disks.keys():
+        for dev in list(self.disks.keys()):
             d = self.disks[dev]
             if d['mapped']:
                 continue
@@ -492,7 +492,7 @@ class PartitionedMount(Mount):
             d['mapped'] = True
 
     def __unmap_partitions(self):
-        for dev in self.disks.keys():
+        for dev in list(self.disks.keys()):
             d = self.disks[dev]
             if not d['mapped']:
                 continue
@@ -526,7 +526,7 @@ class PartitionedMount(Mount):
         Mount.cleanup(self)
         if self.disks:
             self.__unmap_partitions()
-            for dev in self.disks.keys():
+            for dev in list(self.disks.keys()):
                 d = self.disks[dev]
                 try:
                     d['disk'].cleanup()
@@ -764,7 +764,7 @@ class PartitionedMount(Mount):
         self.snapshot_created = True
 
     def mount(self):
-        for dev in self.disks.keys():
+        for dev in list(self.disks.keys()):
             d = self.disks[dev]
             d['disk'].create()
 
