@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/usr/bin/python3 -tt
 #
 # Copyright (c) 2008, 2009, 2010, 2011 Intel, Inc.
 #
@@ -51,12 +51,14 @@ class RPMInstallCallback:
         tmpepoch = hdr['epoch']
         if tmpepoch is None: epoch = '0'
         else: epoch = str(tmpepoch)
-
+        #name, version, release must have value according to spec rule.
         return (hdr['name'], hdr['arch'], epoch, hdr['version'], hdr['release'])
 
     def _makeHandle(self, hdr):
-        handle = '%s:%s.%s-%s-%s' % (hdr['epoch'], hdr['name'], hdr['version'],
-          hdr['release'], hdr['arch'])
+        tmpepoch = hdr['epoch']
+        if tmpepoch is None: epoch = '0'
+        else: epoch = str(tmpepoch) #epoch is 'int' object
+        handle = '%s:%s.%s-%s-%s' % (tmpepoch, hdr['name'], hdr['version'], hdr['release'], hdr['arch'])
 
         return handle
 
@@ -112,7 +114,7 @@ class RPMInstallCallback:
                     rpmloc = h
                     hdr = readRpmHeader(self.ts, h)
 
-                m = re.match("(.*)-(\d+.*)-(\d+\.\d+)\.(.+)\.rpm", os.path.basename(rpmloc))
+                m = re.match(r"(.*)-(\d+.*)-(\d+\.\d+)\.(.+)\.rpm", os.path.basename(rpmloc))
                 if m:
                     pkgname = m.group(1)
                 else:
@@ -161,7 +163,7 @@ class RPMInstallCallback:
                     except:
                         rpmloc = h
 
-                    m = re.match("(.*)-(\d+.*)-(\d+\.\d+)\.(.+)\.rpm", os.path.basename(rpmloc))
+                    m = re.match(r"(.*)-(\d+.*)-(\d+\.\d+)\.(.+)\.rpm", os.path.basename(rpmloc))
                     if m:
                         pkgname = m.group(1)
                     else:
@@ -202,7 +204,7 @@ class RPMInstallCallback:
                 except:
                     rpmloc = h
 
-                m = re.match("(.*)-(\d+.*)-(\d+\.\d+)\.(.+)\.rpm", os.path.basename(rpmloc))
+                m = re.match(r"(.*)-(\d+.*)-(\d+\.\d+)\.(.+)\.rpm", os.path.basename(rpmloc))
                 if m:
                     pkgname = m.group(1)
                 else:
@@ -368,29 +370,29 @@ def isMultiLibArch(arch=None):
     if arch is None:
         arch = getCanonArch()
 
-    if not arches.has_key(arch): # or we could check if it is noarch
+    if arch not in arches: # or we could check if it is noarch
         return False
 
-    if multilibArches.has_key(arch):
+    if arch in multilibArches:
         return True
 
-    if multilibArches.has_key(arches[arch]):
+    if arches[arch] in multilibArches:
         return True
 
     return False
 
 def getBaseArch():
     myarch = getCanonArch()
-    if not arches.has_key(myarch):
+    if myarch not in arches:
         return myarch
 
     if isMultiLibArch(arch=myarch):
-        if multilibArches.has_key(myarch):
+        if myarch in multilibArches:
             return myarch
         else:
             return arches[myarch]
 
-    if arches.has_key(myarch):
+    if myarch in arches:
         basearch = myarch
         value = arches[basearch]
         while value != 'noarch':
