@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/usr/bin/python3 -tt
 #
 # Copyright (c) 2010, 2011 Intel, Inc.
 #
@@ -17,9 +17,10 @@
 
 import os
 import shutil
-import urlparse
+import urllib.parse
 import rpm
 import glob
+import functools
 
 import zypp #pylint: disable=import-error
 if not hasattr(zypp, 'PoolQuery') or \
@@ -193,8 +194,8 @@ class Zypp(BackendPlugin):
 
             ed1 = p1.edition()
             ed2 = p2.edition()
-            (e1, v1, r1) = map(str, [ed1.epoch(), ed1.version(), ed1.release()])
-            (e2, v2, r2) = map(str, [ed2.epoch(), ed2.version(), ed2.release()])
+            (e1, v1, r1) = list(map(str, [ed1.epoch(), ed1.version(), ed1.release()]))
+            (e2, v2, r2) = list(map(str, [ed2.epoch(), ed2.version(), ed2.release()]))
             return rpm.labelCompare((e1, v1, r1), (e2, v2, r2))
 
         found = False
@@ -226,13 +227,13 @@ class Zypp(BackendPlugin):
 
         for pitem in sorted(
                         q.queryResults(self.Z.pool()),
-                        cmp=lambda x,y: cmpEVR(zypp.asKindPackage(x), zypp.asKindPackage(y)),
+                        key=functools.cmp_to_key(lambda x,y: cmpEVR(zypp.asKindPackage(x), zypp.asKindPackage(y))),
                         reverse=True):
             item = zypp.asKindPackage(pitem)
-            if item.name() in self.excpkgs.keys() and \
+            if item.name() in list(self.excpkgs.keys()) and \
                self.excpkgs[item.name()] == item.repoInfo().name():
                 continue
-            if item.name() in self.incpkgs.keys() and \
+            if item.name() in list(self.incpkgs.keys()) and \
                self.incpkgs[item.name()] != item.repoInfo().name():
                 continue
 
@@ -254,13 +255,13 @@ class Zypp(BackendPlugin):
 
             for pitem in sorted(
                             q.queryResults(self.Z.pool()),
-                            cmp=lambda x,y: cmpEVR(zypp.asKindPackage(x), zypp.asKindPackage(y)),
+                            key=functools.cmp_to_key(lambda x,y: cmpEVR(zypp.asKindPackage(x), zypp.asKindPackage(y))),
                             reverse=True):
                 item = zypp.asKindPackage(pitem)
-                if item.name() in self.excpkgs.keys() and \
+                if item.name() in list(self.excpkgs.keys()) and \
                    self.excpkgs[item.name()] == item.repoInfo().name():
                     continue
-                if item.name() in self.incpkgs.keys() and \
+                if item.name() in list(self.incpkgs.keys()) and \
                    self.incpkgs[item.name()] != item.repoInfo().name():
                     continue
 
@@ -303,7 +304,7 @@ class Zypp(BackendPlugin):
         """collect packages should not be installed"""
         self.to_deselect.append(pkg)
 
-    def selectGroup(self, grp, include = ksparser.GROUP_DEFAULT):
+    def selectGroup(self, grp, include = ksparser.constants.GROUP_DEFAULT):
         def compareGroup(pitem):
             item = zypp.asKindPattern(pitem)
             return item.repoInfo().priority()
@@ -322,10 +323,8 @@ class Zypp(BackendPlugin):
                 break
 
         if found:
-            if include == ksparser.GROUP_REQUIRED:
-                map(
-                    lambda p: self.deselectPackage(p),
-                    grp.default_packages.keys())
+            if include == ksparser.constants.GROUP_REQUIRED:
+                list([self.deselectPackage(p) for p in list(grp.default_packages.keys())])
 
             return None
         else:
@@ -387,7 +386,7 @@ class Zypp(BackendPlugin):
             if not ssl_verify:
                 baseurl.setQueryParam("ssl_verify", "no")
             if proxy:
-                host = urlparse.urlparse(proxy)[1]
+                host = urllib.parse.urlparse(proxy)[1]
                 # scheme, host, path, parm, query, frag = urlparse.urlparse(proxy)
 
                 proxyinfo = host.rsplit(":", 1)
@@ -519,7 +518,7 @@ class Zypp(BackendPlugin):
             raise CreatorError('Packages absent in image: %s' % ','.join(self.check_pkgs))
 
         # record all pkg and the content
-        localpkgs = self.localpkgs.keys()
+        localpkgs = list(self.localpkgs.keys())
         for pkg in dlpkgs:
             license = ''
             if pkg.name() in localpkgs:
@@ -542,15 +541,15 @@ class Zypp(BackendPlugin):
 
                 license = pkg.license()
 
-            if license in self.__pkgs_license.keys():
+            if license in list(self.__pkgs_license.keys()):
                 self.__pkgs_license[license].append(pkg_long_name)
             else:
                 self.__pkgs_license[license] = [pkg_long_name]
 
         total_count = len(dlpkgs)
         cached_count = 0
-        download_total_size = sum(map(lambda x: int(x.downloadSize()), dlpkgs))
-        localpkgs = self.localpkgs.keys()
+        download_total_size = sum([int(x.downloadSize()) for x in dlpkgs])
+        localpkgs = list(self.localpkgs.keys())
 
         msger.info("Checking packages cached ...")
         for po in dlpkgs:
@@ -561,7 +560,7 @@ class Zypp(BackendPlugin):
                 local = self.getLocalPkgPath(po)
                 name = str(po.repoInfo().name())
                 try:
-                    repo = filter(lambda r: r.name == name, self.repos)[0]
+                    repo = list(filter(lambda r: r.name == name, self.repos))[0]
                 except IndexError:
                     repo = None
                 nocache = repo.nocache if repo else False
@@ -577,7 +576,7 @@ class Zypp(BackendPlugin):
             raise CreatorError("No enough space used for downloading.")
 
         # record the total size of installed pkgs
-        install_total_size = sum(map(lambda x: int(x.installSize()), dlpkgs))
+        install_total_size = sum([int(x.installSize()) for x in dlpkgs])
         # check needed size before actually download and install
 
         # FIXME: for multiple partitions for loop type, check fails
@@ -736,8 +735,8 @@ class Zypp(BackendPlugin):
 
             for problem in probs:
                 msger.warning("repo problem: %s, %s" \
-                              % (problem.description().decode("utf-8"),
-                                 problem.details().decode("utf-8")))
+                              % (problem.description(),
+                                 problem.details()))
 
             raise RepoError("found %d resolver problem, abort!" \
                             % len(probs))
@@ -756,13 +755,10 @@ class Zypp(BackendPlugin):
 
         solvfile = "%s/.solv" % (self.cachedir)
 
-        rc, out = runner.runtool([fs_related.find_binary_path("rpms2solv"),
-                                  pkg])
-        if rc == 0:
-            f = open(solvfile, "w+")
-            f.write(out)
-            f.close()
-
+        #for python3.x, use subprocess.popen(), it can't deal with the solv contents. the contents
+        #is garbled code. so use redirect way to solvfile directly.
+        os.system('%s %s > %s' % (fs_related.find_binary_path("rpms2solv"), pkg, solvfile))
+        if os.path.exists(solvfile):
             warnmsg = self.repo_manager.loadSolvFile(solvfile,
                                                      os.path.basename(pkg))
             if warnmsg:
@@ -788,7 +784,7 @@ class Zypp(BackendPlugin):
                           % (pkg, hdr['arch']))
 
     def downloadPkgs(self, package_objects, count):
-        localpkgs = self.localpkgs.keys()
+        localpkgs = list(self.localpkgs.keys())
         progress_obj = TextProgress(count)
 
         for po in package_objects:
@@ -875,7 +871,7 @@ class Zypp(BackendPlugin):
         self.ts.setProbFilter(probfilter)
         self.ts_pre.setProbFilter(probfilter)
 
-        localpkgs = self.localpkgs.keys()
+        localpkgs = list(self.localpkgs.keys())
 
         for po in package_objects:
             pkgname = po.name()
@@ -976,7 +972,7 @@ class Zypp(BackendPlugin):
         proxies = None
         repoinfo = pobj.repoInfo()
         reponame = "%s" % repoinfo.name()
-        repos = filter(lambda r: r.name == reponame, self.repos)
+        repos = [r for r in self.repos if r.name == reponame]
         repourl = str(repoinfo.baseUrls()[0])
 
         if repos:
@@ -994,7 +990,7 @@ class Zypp(BackendPlugin):
 
         name = str(pobj.repoInfo().name())
         try:
-            repo = filter(lambda r: r.name == name, self.repos)[0]
+            repo = list(filter(lambda r: r.name == name, self.repos))[0]
         except IndexError:
             return None
 
@@ -1010,8 +1006,8 @@ class Zypp(BackendPlugin):
         def cmpEVR(p1, p2):
             ed1 = p1.edition()
             ed2 = p2.edition()
-            (e1, v1, r1) = map(str, [ed1.epoch(), ed1.version(), ed1.release()])
-            (e2, v2, r2) = map(str, [ed2.epoch(), ed2.version(), ed2.release()])
+            (e1, v1, r1) = list(map(str, [ed1.epoch(), ed1.version(), ed1.release()]))
+            (e2, v2, r2) = list(map(str, [ed2.epoch(), ed2.version(), ed2.release()]))
             return rpm.labelCompare((e1, v1, r1), (e2, v2, r2))
 
         if not self.Z:
@@ -1022,7 +1018,7 @@ class Zypp(BackendPlugin):
         q.setMatchExact()
         q.addAttribute(zypp.SolvAttr.name, pkgname)
         items = sorted(q.queryResults(self.Z.pool()),
-                       cmp=lambda x,y: cmpEVR(zypp.asKindPackage(x), zypp.asKindPackage(y)),
+                       key=functools.cmp_to_key(lambda x,y: cmpEVR(zypp.asKindPackage(x), zypp.asKindPackage(y))),
                        reverse=True)
 
         if items:
