@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/usr/bin/python3 -tt
 #
 # Copyright (c) 2011 Intel, Inc.
 #
@@ -133,7 +133,7 @@ class RawPlugin(ImagerPlugin):
             #  2      3400531968B  3656384511B  255852544B   primary  linux-swap(v1)
             #  3      3656384512B  3720347647B  63963136B    primary  fat16          boot, lba
 
-            partition_info = re.split("\s+", line)
+            partition_info = re.split(r"\s+", line)
 
             size = partition_info[3].split("B")[0]
 
