@@ -267,7 +267,7 @@ class ArchiveTest(unittest.TestCase):
         archive_formats = archive.get_archive_formats()
         archive_formats.sort()
         self.assertEqual(archive_formats,
-                        ["bztar", "gztar", "lzotar", "tar", 'zip'])
+                        ["bztar", "gztar", "lzotar", "tar", 'zip', 'zsttar'])
 
     def test_get_archive_suffixes(self):
         """Test get archive suffixes"""
@@ -275,7 +275,7 @@ class ArchiveTest(unittest.TestCase):
         archive_suffixes.sort()
 
         self.assertEqual(archive_suffixes,
-                         ['.tar', '.tar.bz', '.tar.bz2', '.tar.gz', '.tar.lzo',
+                         ['.tar', '.tar.bz', '.tar.bz2', '.tar.gz', '.tar.lzo','.tar.zst',
                          '.taz', '.tbz', '.tbz2', '.tgz', '.tzo', '.zip'])
 
     def test_make_archive_negtive_archive_name_is_required(self):
@@ -688,5 +688,22 @@ class ArchiveTest(unittest.TestCase):
             self.assertTrue(os.path.exists(os.path.join(out_dir, item)))
             shutil.rmtree(out_dir)
 
+    def test_make_archive_tar_zst_with_different_name(self):
+        """ Test make_archive format: tar.zst
+            it packs the source with another name """
+        for item in self.files + self.dirs:
+            out_file = 'df.tar.zst'
+            self.assertTrue(archive.make_archive(out_file, item))
+            self.assertTrue(os.path.exists(out_file))
+            os.remove(out_file)
+
+    def test_make_archive_tar_zst(self):
+        """ Test make_archive format: tar.zst"""
+        for item in self.files + self.dirs:
+            out_file = '%s.tar.zst' % item
+            self.assertTrue(archive.make_archive(out_file, item))
+            self.assertTrue(os.path.exists(out_file))
+            os.remove(out_file)
+
 if __name__ == "__main__":
     unittest.main()
