@@ -1,8 +1,8 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 
 import os
 import sys
-import StringIO
+import io
 import unittest
 from mic.utils import runner
 
@@ -14,8 +14,8 @@ class RunnerTest(unittest.TestCase):
     def setUp(self):
         self.stdout = sys.stdout
         self.stderr = sys.stderr
-        sys.stdout = StringIO.StringIO()
-        sys.stderr = StringIO.StringIO()
+        sys.stdout = io.StringIO()
+        sys.stderr = io.StringIO()
 
     def tearDown(self):
         sys.stdout = self.stdout
